import BatteryBox from "./components/BatteryBox";
import TemperatureBox from "./components/TemperatureBox";
import WindBox from "./components/WindBox";
import MissionCompleteRateBox from "./components/MissionCompleteRateBox";
import CurrentStateBox from "./components/CurrentStateBox";
import WheelSpeedBox from "./components/WheelSpeedBox";
import TopBar from "./components/TopBar";
import CompletedMissionTable from "./components/CompletedMissionTable";
import ActiveMissionTable from "./components/ActiveMissionTable";
import StatisticsBox from "./components/StatisticsBox";
import InventoryBox from "./components/InventoryBox";
import styles from "./styles/DashboardScreen.module.scss";
import { forwardRef, useState } from "react";
import "./styles/styles.css";
import SettingsDrawer from "./components/SettingsDrawer";
import SeismicBox from "./components/SeismicBox";

const DashboardScreen = forwardRef((props, ref: any) => {
  //State for the settings drawer
  const [open, setOpen] = useState(false);

  //Callback to open the settings drawer
  const showDrawer = () => {
    setOpen(true);
  };

  return (
    <div className={styles.scrollBarCon}>
      <div
        style={{
          padding: 20,
          background:
            "radial-gradient(circle, rgba(0,146,255,1) 0%, rgba(0,56,98,1) 55%, rgba(0,20,34,1) 100%)",
        }}
      >
        <TopBar showDrawer={showDrawer} />
        <div
          style={{
            display: "flex",
            justifyContent: "space-between",
            marginTop: 20,
          }}
        >
          <BatteryBox ref={ref} />
          <TemperatureBox ref={ref} />
          <SeismicBox ref={ref} />
          <WindBox ref={ref} />
        </div>
        <div
          style={{
            display: "flex",
            justifyContent: "space-between",
            marginTop: 20,
          }}
        >
          <CurrentStateBox ref={ref} />
          <MissionCompleteRateBox />
          <WheelSpeedBox />
        </div>
        <div
          style={{
            display: "flex",
            justifyContent: "space-between",
            marginTop: 20,
          }}
        >
          <CompletedMissionTable />
          <ActiveMissionTable />
        </div>
        <div
          style={{
            display: "flex",
            justifyContent: "space-between",
            marginTop: 20,
          }}
        >
          <StatisticsBox />
          <InventoryBox ref={ref} />
        </div>
      </div>
      <SettingsDrawer open={open} onClose={() => setOpen(false)} />
    </div>
  );
});

export default DashboardScreen;
