import { Table, Typography } from "antd";
import { AiFillCheckCircle } from "react-icons/ai";
import type { ColumnsType } from "antd/es/table";

interface DataType {
  id: number;
  task: string;
  completedTime: string;
}

const columns: ColumnsType<DataType> = [
  {
    title: "Nr.",
    dataIndex: "id",
    key: "id",
    render: (id) => <>{id}</>,
  },
  {
    title: "Task",
    dataIndex: "task",
    key: "task",
    render: (task) => <>{task}</>,
  },
  {
    title: "Completed Time",
    dataIndex: "completedTime",
    key: "completedTime",
    render: (completedTime) => <>{completedTime}</>,
  },
];

const data: DataType[] = [
  {
    id: 1,
    task: "Pick up sensor",
    completedTime: "2023-03-06 12:00:10",
  },
  {
    id: 2,
    task: "Walk to new position",
    completedTime: "2023-03-06 12:00:10",
  },
  {
    id: 3,
    task: "Drop sensor",
    completedTime: "2023-03-06 12:00:10",
  },
];

//This component shows the steps for the current mission
// ,the information comes from task planning
const ActiveMissionTable = () => {
  return (
    <div
      style={{
        width: "34%",
        height: 350,
        background:
          "linear-gradient(300deg, rgba(40,40,40,0.8) 0%, rgba(0,0,0,0.8) 100%)",
        borderRadius: 15,
        display: "flex",
        alignItems: "flex-start",
        padding: 15,
        flexDirection: "column",
      }}
    >
      <Typography.Text
        strong
        style={{ color: "white", margin: 0, fontSize: 28 }}
      >
        Active Mission
      </Typography.Text>
      <div
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
        }}
      >
        <Typography.Text
          strong
          style={{
            color: "green",
            margin: "0px 6px 0px 0px",
            fontSize: 14,
          }}
        >
          <AiFillCheckCircle />
        </Typography.Text>
        <Typography.Text
          strong
          style={{
            color: "gray",
            margin: "0px 0px 0px 0px",
            fontSize: 14,
          }}
        >
          0 tasks completed
        </Typography.Text>
      </div>
      <div
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
          margin: "10px 0px 0px 0px",
          width: "100%",
        }}
      >
        <Table
          columns={columns}
          dataSource={[]}
          pagination={false}
          style={{ width: "100%" }}
          rowKey={(row) => row.id}
        />
      </div>
    </div>
  );
};

export default ActiveMissionTable;
