import { Button, Space, Typography } from "antd";
import { forwardRef, useEffect, useState } from "react";
import { BsFillLightningChargeFill } from "react-icons/bs";

const BatteryBox = forwardRef((props, ref: any) => {
  //State that holds the battery level
  const [battery, setBattery] = useState(100);

  //State that holds the in shadow zone property
  const [inShadow, setInShadow] = useState(false);

  //Interval that updates the battery and shadow zone each second
  //based on the forwarded ref that holds all the information
  useEffect(() => {
    const interval = setInterval(() => {
      if (!ref) return;
      if (ref.current.robot.battery !== battery)
        setBattery(ref.current.robot.battery);
      if (ref.current.robot.in_shadow !== inShadow)
        setInShadow(ref.current.robot.in_shadow);
    }, 1000);

    return () => clearInterval(interval);
  }, [ref, battery, inShadow]);

  return (
    <div
      style={{
        width: "24%",
        height: 80,
        background:
          "linear-gradient(300deg, rgba(40,40,40,0.8) 0%, rgba(0,0,0,0.8) 100%)",
        borderRadius: 15,
        display: "flex",
        justifyContent: "space-between",
        alignItems: "center",
        padding: 15,
      }}
    >
      <div>
        <div style={{ display: "flex", flexDirection: "column" }}>
          <Typography.Text
            strong
            style={{
              color: "gray",
              margin: "0px 0px -10px 0px",
              fontSize: 14,
            }}
          >
            Battery
          </Typography.Text>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 24 }}
            >
              {battery.toFixed(2)}%
            </Typography.Text>
            <Typography.Text
              strong
              style={{
                color: inShadow ? "red" : "green",
                margin: 0,
                fontSize: 12,
              }}
            >
              {inShadow ? "NOT CHARGING" : "CHARGING"}
            </Typography.Text>
          </Space>
        </div>
      </div>
      <Button
        type="primary"
        size="large"
        danger
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
        }}
      >
        <BsFillLightningChargeFill />
      </Button>
    </div>
  );
});

export default BatteryBox;
