import { Button, Progress, Table, Typography } from "antd";
import { AiFillCheckCircle } from "react-icons/ai";
import type { ColumnsType } from "antd/es/table";
import { useEffect, useState } from "react";
import { Demo } from "../../models/Replay";
import { getDemos, updateDemoName } from "../../functions/Supabase";
import moment from "moment";
import { useNavigate } from "react-router-dom";

interface DataType {
  id: number;
  name: string;
  time: string;
  completedRate: number;
}

//This component shows the missions recorded
const CompletedMissionTable = () => {
  //State that holds all the demos loaded from Supabase backend
  const [displayedDemos, setDisplayedDemos] = useState<DataType[]>([]);

  //Loading is set to true while the demos are being loaded from the backend
  const [loading, setLoading] = useState<boolean>(true);

  const navigate = useNavigate();

  const columns: ColumnsType<DataType> = [
    {
      title: "Name",
      key: "name",
      render: ({ id, name }: DataType) => (
        <Typography.Text
          editable={{
            onChange: (e) => {
              updateDemoName(id, e);
              let temp = displayedDemos;
              for (let i = 0; i < temp.length; i++) {
                if (temp[i].id === id) {
                  temp[i].name = e;
                  break;
                }
              }
              setDisplayedDemos([...temp]);
            },
          }}
        >
          {name}
        </Typography.Text>
      ),
    },
    {
      title: "Time",
      dataIndex: "time",
      key: "time",
      render: (time) => (
        <Typography.Text>
          {moment(time).format("YYYY-MM-DD HH:mm:ss")}
        </Typography.Text>
      ),
    },
    {
      title: "Completed Rate",
      dataIndex: "completedRate",
      key: "completedRate",
      render: (completedRate) => <>{<Progress percent={completedRate} />}</>,
    },
    {
      title: "",
      key: "action",
      render: ({ id }: DataType) => (
        <>
          <Button onClick={() => navigate(`/replay/${id}`)}>Play</Button>
        </>
      ),
    },
  ];

  useEffect(() => {
    const fetchDemos = async () => {
      return await getDemos();
    };
    fetchDemos().then((data: Demo[]) => {
      let demoList = [] as DataType[];
      for (let i = 0; i < data.length; i++) {
        const currentDemo = data[i];
        let newEntry = {
          id: currentDemo.id,
          name: currentDemo.name,
          completedRate: 100,
          time: currentDemo.created_at,
        } as DataType;
        demoList.push(newEntry);
      }
      setDisplayedDemos(demoList);
      setLoading(false);
    });
  }, []);

  return (
    <div
      style={{
        width: "64%",
        height: 350,
        background:
          "linear-gradient(300deg, rgba(40,40,40,0.8) 0%, rgba(0,0,0,0.8) 100%)",
        borderRadius: 15,
        display: "flex",
        alignItems: "flex-start",
        padding: 15,
        flexDirection: "column",
      }}
    >
      <Typography.Text
        strong
        style={{ color: "white", margin: 0, fontSize: 28 }}
      >
        Completed Missions
      </Typography.Text>
      <div
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
        }}
      >
        <Typography.Text
          strong
          style={{
            color: "green",
            margin: "0px 6px 0px 0px",
            fontSize: 14,
          }}
        >
          <AiFillCheckCircle />
        </Typography.Text>
        <Typography.Text
          strong
          style={{
            color: "gray",
            margin: "0px 0px 0px 0px",
            fontSize: 14,
          }}
        >
          {displayedDemos.length}{" "}
          {`${displayedDemos.length > 1 ? "missions" : "mission"}`} completed
          this month.
        </Typography.Text>
      </div>
      <div
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
          margin: "10px 0px 0px 0px",
          width: "100%",
        }}
      >
        <Table
          columns={columns}
          dataSource={[...displayedDemos]}
          pagination={false}
          style={{ width: "100%" }}
          rowKey={(row) => row.id}
          loading={loading}
          scroll={{ y: 200 }}
        />
      </div>
    </div>
  );
};

export default CompletedMissionTable;
