import { Button, Divider, Space, Typography } from "antd";
import { forwardRef, useEffect, useState } from "react";
import { AiOutlineArrowRight } from "react-icons/ai";
import { useNavigate } from "react-router-dom";
import stateBG from "../../assets/robotStateBG.png";
import { Conclusion, Position } from "../../models/Data";


//This comonents shows the current state of the rover
// it includes its position, autopilot mode, and the conclusions
// from the situation reporting group
const CurrentStateBox = forwardRef((props, ref: any) => {
  const navigate = useNavigate();

  //State for the robot position, r stands for rotation, x,y are coordinates
  const [robotPosition, setRobotPosition] = useState<Position>({
    r: 0,
    x: 0,
    y: 0,
  });

  //This information comes from the situation reporting group
  const [conclusion, setConclusion] = useState<Conclusion>({
    status: 1,
    tornado: 0,
    earthquake: 0,
    vulcano: 0,
  });

  //Autopilot mode can be turned on and off from the user interface
  const [autopilot, setAutopilot] = useState<boolean>(true);

  //Updates the states above each 1s
  useEffect(() => {
    const interval = setInterval(() => {
      if (ref.current.robot.pos !== robotPosition)
        setRobotPosition({ ...ref.current.robot.pos });
      if (ref.current.conclusion !== conclusion)
        setConclusion(ref.current.conclusion);
      if (ref.current.autopilot !== autopilot)
        setAutopilot(ref.current.autopilot);
    }, 1000);

    return () => clearInterval(interval);
  }, [ref, robotPosition, conclusion, autopilot]);

  return (
    <div
      style={{
        width: "40%",
        height: 350,
        backgroundImage: `url(${stateBG})`,
        backgroundRepeat: "no-repeat",
        backgroundPosition: "center",
        borderRadius: 15,
        display: "flex",
        justifyContent: "space-between",
        flexDirection: "column",
        padding: 15,
      }}
    >
      <div>
        <div style={{ display: "flex", flexDirection: "column" }}>
          <Typography.Text
            strong
            style={{
              color: "gray",
              margin: "0px 0px -10px 0px",
              fontSize: 14,
            }}
          >
            Current State of the
          </Typography.Text>
          <Typography.Text
            strong
            style={{ color: "white", margin: 0, fontSize: 42 }}
          >
            Mars Rover
          </Typography.Text>
        </div>
        <div style={{ display: "flex", flexDirection: "column" }}>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 20 }}
            >
              Autopilot
            </Typography.Text>
            <Typography.Text
              strong
              style={{ color: "gray", margin: 0, fontSize: 20 }}
            >
              {" "}
              {autopilot ? "On" : "Off"}
            </Typography.Text>
          </Space>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 20 }}
            >
              Position
            </Typography.Text>
            <Typography.Text
              strong
              style={{ color: "gray", margin: 0, fontSize: 20 }}
            >
              {" "}
              ({robotPosition.r.toPrecision(2)},{robotPosition.x.toPrecision(2)}
              ,{robotPosition.y.toPrecision(2)})
            </Typography.Text>
          </Space>
          <Divider />
          <Typography.Text
            strong
            style={{
              color: "gray",
              margin: "-10px 0px 0px 0px",
              fontSize: 14,
            }}
          >
            Current Conclusion
          </Typography.Text>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 20 }}
            >
              Earthquake
            </Typography.Text>
            <Typography.Text
              strong
              style={{ color: "gray", margin: 0, fontSize: 20 }}
            >
              {` ${
                conclusion.status === 1
                  ? "Unknown"
                  : conclusion.earthquake === 0
                  ? "No"
                  : "Yes"
              }`}
            </Typography.Text>
          </Space>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 20 }}
            >
              Tornado
            </Typography.Text>
            <Typography.Text
              strong
              style={{ color: "gray", margin: 0, fontSize: 20 }}
            >
              {` ${
                conclusion.status === 1
                  ? "Unknown"
                  : conclusion.tornado === 0
                  ? "No"
                  : "Yes"
              }`}
            </Typography.Text>
          </Space>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 20 }}
            >
              Volcano
            </Typography.Text>
            <Typography.Text
              strong
              style={{ color: "gray", margin: 0, fontSize: 20 }}
            >
              {` ${
                conclusion.status === 1
                  ? "Unknown"
                  : conclusion.vulcano === 0
                  ? "No"
                  : "Yes"
              }`}
            </Typography.Text>
          </Space>
        </div>
      </div>
      <Button
        type="text"
        style={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
        }}
        onClick={() => navigate("/map")}
      >
        <Typography.Text
          style={{ color: "white", marginRight: 5, fontSize: 14 }}
        >
          Tap to open fullscreen
        </Typography.Text>
        <AiOutlineArrowRight />
      </Button>
    </div>
  );
});

export default CurrentStateBox;
