import { Button, Dropdown, Select, Space, theme, Typography } from "antd";
import { forwardRef, useEffect, useRef, useState } from "react";
import { WiEarthquake } from "react-icons/wi";

const { useToken } = theme;

const SeismicBox = forwardRef((props, ref: any) => {
  //Holds all the sensor ids
  const [sensorList, setSensorList] = useState<any[]>([]);
  const [seismic, setSeismic] = useState<number[]>([0, 0]);
  const [selectedId, setSelectedId] = useState<number>(-1);
  const sensorCounterRef = useRef<number>(-1);

  //Checks for a change in sensors each 1s, if a change has happend it will update the
  // sensors list
  useEffect(() => {
    const interval = setInterval(() => {
      if (!ref) return;
      //Update the seismic value
      if (selectedId !== -1) {
        const selectedSensor = ref.current.sensors.find(
          (s: any) => s.id === selectedId
        );
        if (!selectedSensor) return;
        const newSeismic = selectedSensor.shake_val as number;
        let newArray = [...seismic];
        newArray.shift();
        newArray.push(newSeismic);
        setSeismic(newArray);
      }

      //This runs if there are new sensors to be added to the list
      if (sensorList.length !== sensorCounterRef.current) {
        let tempSensorIds = [];
        for (let i = 0; i < ref.current.sensors.length; i++) {
          const currentSensor = ref.current.sensors[i];
          if ("shake_val" in currentSensor) {
            tempSensorIds.push({
              value: currentSensor.id,
              label: `Seismic ${currentSensor.id}`,
            });
          }
        }
        sensorCounterRef.current = sensorList.length;
        setSensorList(tempSensorIds);
      }
    }, 2000);

    return () => clearInterval(interval);
  }, [ref, sensorList, selectedId, seismic]);

  const { token } = useToken();

  const contentStyle = {
    backgroundColor: token.colorBgElevated,
    borderRadius: token.borderRadiusLG,
    boxShadow: token.boxShadowSecondary,
  };

  return (
    <div
      style={{
        width: "24%",
        height: 80,
        background:
          "linear-gradient(300deg, rgba(40,40,40,0.8) 0%, rgba(0,0,0,0.8) 100%)",
        borderRadius: 15,
        display: "flex",
        justifyContent: "space-between",
        alignItems: "center",
        padding: 15,
      }}
    >
      <div>
        <div style={{ display: "flex", flexDirection: "column" }}>
          <Typography.Text
            strong
            style={{
              color: "gray",
              margin: "0px 0px -10px 0px",
              fontSize: 14,
            }}
          >
            Seismic
          </Typography.Text>
          <Space>
            <Typography.Text
              strong
              style={{ color: "white", margin: 0, fontSize: 24 }}
            >
              {seismic[1].toFixed(2)}
            </Typography.Text>
            <Typography.Text
              strong
              style={{
                color: seismic[0] - seismic[1] > 0 ? "red" : "green",
                margin: 0,
                fontSize: 12,
              }}
            >
              {seismic[0] - seismic[1] > 0
                ? `-${(seismic[0] - seismic[1]).toFixed(2)}`
                : `+${Math.abs(seismic[0] - seismic[1]).toFixed(2)}`}
            </Typography.Text>
          </Space>
        </div>
      </div>
      <Dropdown
        trigger={["click"]}
        placement="bottom"
        dropdownRender={(menu) => (
          <div style={contentStyle}>
            <Select
              placeholder="Sensor ID"
              style={{ width: 200 }}
              options={sensorList}
              onChange={(value: number | null) => {
                if (value !== null) {
                  setSelectedId(value);
                  setSeismic([0, 0]);
                }
              }}
            />
          </div>
        )}
      >
        <Button
          type="primary"
          size="large"
          style={{
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            fontSize: 24,
          }}
        >
          <WiEarthquake />
        </Button>
      </Dropdown>
    </div>
  );
});

export default SeismicBox;
