import { Col, Divider, Drawer, Row, InputNumber } from "antd";
import moment from "moment";
import { useContext } from "react";
import MQTTContext from "../../state/MQTT";

interface Props {
  open: boolean;
  onClose: () => void;
}

interface DescriptionItemProps {
  title: string;
  content: React.ReactNode;
}

const DescriptionItem = ({ title, content }: DescriptionItemProps) => (
  <div className="site-description-item-profile-wrapper">
    <p className="site-description-item-profile-p-label">{title}:</p>
    {content}
  </div>
);

const SettingsDrawer = ({ open, onClose }: Props) => {
  const { config } = useContext(MQTTContext);

  return (
    <Drawer
      width={640}
      placement="right"
      closable={false}
      onClose={onClose}
      open={open}
      style={{
        background: "rgba(0,40,70,1)",
      }}
    >
      <p
        className="site-description-item-profile-p"
        style={{ marginBottom: 24 }}
      >
        Settings
      </p>
      <p className="site-description-item-profile-p">MQTT</p>
      <Row>
        <Col span={24}>
          <DescriptionItem title="Host" content={config.host} />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Region" content="Europe" />
        </Col>
        <Col span={12}>
          <DescriptionItem title="Port" content={config.port} />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Protocol" content="wss" />
        </Col>
        <Col span={12}>
          <DescriptionItem title="Path" content="/mqtt" />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Compression" content={config.compression} />
        </Col>
        <Col span={12}>
          <DescriptionItem
            title="Encoding"
            content={config.messagepack ? "MessagePack" : "None"}
          />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Client ID" content={config.clientId} />
        </Col>
      </Row>
      <Divider />
      <p className="site-description-item-profile-p">Supabase</p>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Region" content="Europe" />
        </Col>
        <Col span={12}>
          <DescriptionItem title="Cloud Provider" content="AWS" />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Project" content="UserInterfaceOru" />
        </Col>
        <Col span={12}>
          <DescriptionItem
            title="Reference ID"
            content="psyftzqyawclqrrqumek"
          />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem title="Postgres Version" content="15.1.0.37" />
        </Col>
      </Row>
      <Divider />
      <p className="site-description-item-profile-p">General Information</p>
      <Row>
        <Col span={12}>
          <DescriptionItem title="React Version" content="18.2.0" />
        </Col>
        <Col span={12}>
          <DescriptionItem title="Three Version" content="0.148.0" />
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          <DescriptionItem
            title="Latest Update:"
            content={moment().format("YYYY-MM-DD")}
          />
        </Col>
        <Col span={12}>
          <DescriptionItem title="Patch" content="3.0.5" />
        </Col>
      </Row>
    </Drawer>
  );
};

export default SettingsDrawer;
