import React from "react";
import {
  Button,
  Divider,
  Dropdown,
  MenuProps,
  Space,
  theme,
  Typography,
} from "antd";
import {
  SettingOutlined,
  BellOutlined,
  UserOutlined,
  FolderOpenOutlined,
} from "@ant-design/icons";

const { useToken } = theme;

const items: MenuProps["items"] = [
  /*
Example:
  {
    key: "1",
    label: <p>2023-03-05 23:01 | New mission started</p>,
  },
*/
];

interface Props {
  showDrawer: () => void;
}

const TopBar = ({ showDrawer }: Props) => {
  const { token } = useToken();

  const contentStyle = {
    backgroundColor: token.colorBgElevated,
    borderRadius: token.borderRadiusLG,
    boxShadow: token.boxShadowSecondary,
  };

  const menuStyle = {
    boxShadow: "none",
  };

  return (
    <div style={{ display: "flex", justifyContent: "space-between" }}>
      <Typography.Text strong>Dashboard</Typography.Text>
      <Space direction="horizontal">
        <Button type="text">
          <UserOutlined />
          Admin
        </Button>
        <Button type="text" onClick={() => showDrawer()}>
          <SettingOutlined />
        </Button>
        <Dropdown
          trigger={["click"]}
          menu={{ items }}
          dropdownRender={(menu) => (
            <div style={contentStyle}>
              {items.length === 0 ? (
                <Space
                  style={{
                    padding: 20,
                    display: "flex",
                    justifyContent: "center",
                    alignItems: "center",
                  }}
                  direction="vertical"
                >
                  <FolderOpenOutlined
                    style={{
                      color: "white",
                      margin: 0,
                      fontSize: 32,
                    }}
                  />
                  <Typography.Text
                    strong
                    style={{
                      color: "white",
                      margin: 0,
                      fontSize: 16,
                    }}
                  >
                    Nothing to show here.
                  </Typography.Text>
                </Space>
              ) : (
                React.cloneElement(menu as React.ReactElement, {
                  style: menuStyle,
                })
              )}
              <Divider style={{ margin: 0 }} />
              <Space style={{ padding: 8 }}>
                <Button type="primary" danger disabled={items.length === 0}>
                  Clear
                </Button>
              </Space>
            </div>
          )}
        >
          <Button type="text">
            <BellOutlined />
          </Button>
        </Dropdown>
      </Space>
    </div>
  );
};

export default TopBar;
