import { encode } from "messagepack";
import Pako from "pako";
import supabase from "../supabase/Supabase";
import { Buffer } from "buffer";
import moment from "moment";
import { Demo } from "../models/Replay";

export const getDemos = async (): Promise<Demo[]> => {
  try {
    //SET LOADING TRUE HERE
    const { data, error, status } = await supabase.from("Demo").select();

    if (error && status !== 406) {
      throw error;
    }

    if (data) {
      if (data.length !== 0) {
        const uData = data as unknown;
        let tempData = uData as Demo[];
        return tempData;
      }
    }
  } catch (error: any) {
    console.log(error.message);
  } finally {
    //SET LOADING FALSE HERE
  }
  return [];
};

const getDemoRecordId = async (): Promise<number> => {
  const data = await getDemos();
  if (data) {
    if (data.length !== 0) {
      const uData = data as unknown;
      let tempData = uData as Demo[];
      return tempData[tempData.length - 1].id;
    }
  }
  return -1;
};

const postDemoRecord = async () => {
  try {
    const { error } = await supabase
      .from("Demo")
      .insert([{ name: "unnamed", created_at: moment() }]);
    if (error) {
      throw error;
    }
  } catch (error: any) {
    console.log(error.message);
  } finally {
    //setLoading(false)
  }
};

export const uploadDemo = async (data: any) => {
  //com.
  if (!data) {
    console.error("Error: No data");
    return;
  }

  //COMPRESS
  const buffer = Buffer.from(Pako.deflate(encode(data), { level: 9 }));

  //com.
  const file = new Blob([buffer], { type: "text/plain" });

  //com.
  if (!file) {
    console.error("Error: Could not create file");
    return;
  }

  //Upload demo record to SQL table
  await postDemoRecord();
  const newId = await getDemoRecordId();

  //com.
  const { error } = await supabase.storage
    .from("replay")
    .upload(`demo_${newId}.txt`, file);

  //com.
  if (error) {
    console.error(error);
    return;
  }

  console.log("Demo uploaded successfully");
  console.log(file);
};

export function blobToArrayBuffer(blob: any) {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();

    reader.onload = () => {
      const arrayBuffer = reader.result;
      resolve(arrayBuffer);
    };

    reader.onerror = () => {
      reject(reader.error);
    };

    reader.readAsArrayBuffer(blob);
  });
}

export const updateDemoName = async (id: number, name: string) => {
  const { data, error } = await supabase
    .from("Demo")
    .update({ name: name })
    .eq("id", id);
};
