import { forwardRef, Suspense } from "react";
import { Canvas } from "@react-three/fiber";
import Objects from "./components/objects/Objects";
import SatellitePlane from "./components/objects/plane/SatellitePlane";
import Camera from "./components/Camera";
import Overlay from "./components/overlay/Overlay";
import Loader from "./components/Loader";
import Controller from "./components/Controller";
import Lights from "./Lights";
import InteractionPlane from "./components/objects/plane/InteractionPlane";
import { Position2 } from "../models/Data";
import { Stats } from "@react-three/drei";
import ShadowPlane from "./components/objects/plane/ShadowPlane";
import { vec3 } from "../functions/Map";
import ProbabilityPlane from "./components/objects/plane/ProbabilityPlane";

interface Props {
  source: string;
  replay: boolean;
  switchAutopilot: (() => void) | undefined;
  switchRecord: (() => void) | undefined;
  setHoveredCoordinate: ((position: Position2) => void) | undefined;
}

const MapScreen = forwardRef(
  (
    {
      source,
      replay,
      switchAutopilot,
      switchRecord,
      setHoveredCoordinate,
    }: Props,
    ref: any
  ) => {
    console.log(source);
    return (
      <div
        style={{
          height: "100vh",
          width: "100vw",
          background: "black",
        }}
      >
        <Canvas
          shadows
          style={{
            height: "100vh",
            width: "100vw",
          }}
        >
          <Suspense fallback={<Loader />}>
            <Objects replay={replay} ref={ref} />
            <SatellitePlane ref={ref} />
            <Camera ref={ref} />
            <group visible={!replay} key={-2}>
              <InteractionPlane
                ref={ref}
                setHoveredCoordinate={setHoveredCoordinate!}
              />
              <Controller />
            </group>
            <Lights />
            <ShadowPlane
              ref={ref} //position={vec3(-400,-100,-200)}
            />
            <ProbabilityPlane
              ref={ref} //position={vec3(-400,-100,-200)}
            />
          </Suspense>
        </Canvas>
        <Overlay
          ref={ref}
          replay={replay}
          switchAutopilot={switchAutopilot!}
          switchRecord={switchRecord!}
        />
      </div>
    );
  }
);

export default MapScreen;
