import { useCallback, useContext, useEffect } from "react";
import { vec3 } from "../../functions/Map";
import { CameraState } from "../../models/Map";
import MapContext from "../../state/Map";
import MQTTContext from "../../state/MQTT";
import RobotContext from "../../state/Robot";
const Controller = () => {
  const {
    interactionMode,
    cameraState,
    recentlyPressed,
    setInteractionMode,
    setCameraState,
    setSelectedGrid,
    setSelectedPlaneSquare,
    setRecentlyPressed,
  } = useContext(RobotContext);
  const { menuModalIsOpen, setMenuModalIsOpen } = useContext(MapContext);
  const { config, send } = useContext(MQTTContext);

  const keyPress = useCallback(
    (event: KeyboardEvent) => {
      if (event.code === "Escape") {
        if (interactionMode !== "none") {
          let tempCameraState = {} as CameraState;
          tempCameraState.target = "Robot";
          tempCameraState.position = "Robot";
          tempCameraState.zoom = 1.0;
          tempCameraState.sensorId = 0;
          setCameraState(tempCameraState);
          setInteractionMode("none");
          setSelectedGrid(undefined);
          setSelectedPlaneSquare(undefined);
        } else if (menuModalIsOpen) setMenuModalIsOpen(false);
        else if (!menuModalIsOpen) setMenuModalIsOpen(true);
      }
      if (event.key === "r") {
        send(`sim/${config.id}/in/control`, {
          type: "request_satellite_image",
          data: {},
        });
        console.log("Request image");
      }
      if (event.key === "w")
        send(`sim/${config.id}/in/control`, {
          type: "motors",
          data: { left: 0.5, right: 0.5 },
        });
      if (event.key === "a")
        send(`sim/${config.id}/in/control`, {
          type: "motors",
          data: { left: -0.05, right: 0.05 },
        });
      if (event.key === "s")
        send(`sim/${config.id}/in/control`, {
          type: "motors",
          data: { left: -0.5, right: -0.5 },
        });
      if (event.key === "d")
        send(`sim/${config.id}/in/control`, {
          type: "motors",
          data: { left: 0.05, right: -0.05 },
        });
      if (event.code === "Space")
        send(`sim/${config.id}/in/control`, {
          type: "motors",
          data: { left: 0.0, right: 0.0 },
        });
      if (event.key === "i") {
        setSelectedGrid(undefined);
        let tempCameraState = {} as CameraState;
        tempCameraState.target = "Origo";
        tempCameraState.position = "God";
        tempCameraState.zoom = 1.0;
        tempCameraState.sensorId = 0;
        setCameraState(tempCameraState);
        setInteractionMode("selectZone");
      }
      if (event.key === "c") {
        let tempCameraState = {} as CameraState;

        if (recentlyPressed === true) {
          tempCameraState.target = "Robot";
          setRecentlyPressed(false);
        } else {
          tempCameraState.target = vec3(0, 0, 0);
          setRecentlyPressed(true);
        }

        tempCameraState.position = "Robot";
        tempCameraState.zoom = 1.0;
        setCameraState(tempCameraState);
      }

      if (event.key === "+") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.y > -50
        )
          return;
        //com.
        else if (tempCameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.y = tempCameraState.position.y + 25;

        setCameraState(tempCameraState);
      }
      if (event.key === "-") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.y < -600
        )
          return;
        //com.
        else if (cameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.y = tempCameraState.position.y - 25;

        setCameraState(tempCameraState);
      }
      if (event.key === "ArrowUp") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.z > 600
        )
          return;
        //com.
        else if (cameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.z = tempCameraState.position.z + 25;

        setCameraState(tempCameraState);
      }
      if (event.key === "ArrowDown") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.z < -600
        )
          return;
        //com.
        else if (cameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.z = tempCameraState.position.z - 25;

        setCameraState(tempCameraState);
      }
      if (event.key === "ArrowRight") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.x > 600
        )
          return;
        //com.
        else if (cameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.x = tempCameraState.position.x + 25;

        setCameraState(tempCameraState);
      }
      if (event.key === "ArrowLeft") {
        let tempCameraState = { ...cameraState } as any;
        //com.
        if (
          tempCameraState.position === "Robot" ||
          tempCameraState.position === "Sensor" ||
          tempCameraState.position.x < -600
        )
          return;
        //com.
        else if (cameraState.position === "God")
          tempCameraState.position = vec3(0, -600, 0);

        //com.
        tempCameraState.position.x = tempCameraState.position.x - 25;

        setCameraState(tempCameraState);
      }
    },
    [
      interactionMode,
      menuModalIsOpen,
      cameraState,
      config.id,
      recentlyPressed,
      setRecentlyPressed,
      setMenuModalIsOpen,
      setInteractionMode,
      setCameraState,
      send,
      setSelectedGrid,
      setSelectedPlaneSquare,
    ]
  );

  useEffect(() => {
    document.addEventListener("keydown", keyPress);
    return () => document.removeEventListener("keydown", keyPress);
  }, [keyPress]);

  return <mesh></mesh>;
};

export default Controller;
