import { useRef, useState } from "react";
import { Euler, Vector3 } from "three";

interface Props {
  position: Vector3;
  rotation: Euler;
  color: string;
}

const Box = ({ position, rotation, color }: Props) => {
  // This reference gives us direct access to the THREE.Mesh object
  const ref = useRef();
  // Hold state for hovered and clicked events
  const [hovered, hover] = useState(false);
  const [clicked, click] = useState(false);

  // Return the view, these are regular Threejs elements expressed in JSX
  return (
    <mesh
      position={position}
      rotation={rotation}
      ref={ref.current}
      scale={clicked ? 1.5 : 1}
      onPointerOver={(event) => hover(true)}
      onPointerOut={(event) => hover(false)}
    >
      <boxGeometry args={[1, 1, 1]} />
      <meshStandardMaterial color={hovered ? "orange" : color} />
    </mesh>
  );
};

export default Box;
