import { DoubleSide, Vector3 } from "three";
import { useContext, useState } from "react";
import RobotContext from "../../../state/Robot";
import CameraState from "../../../state/Robot";
import { rot3 } from "../../../functions/Map";
import { Html } from "@react-three/drei";
import { Button, Dropdown, MenuProps } from "antd";
import { RightOutlined } from "@ant-design/icons";

interface ZoneProps {
  id: number;
  position: Vector3;
}

interface CylinderProps {
  position: Vector3;
}

export const ZoneObject = ({ id, position }: ZoneProps) => {
  return (
    <group key={id}>
      <Zone position={position} />
    </group>
  );
};

const Zone = ({ position }: CylinderProps) => {
  const { autopilot } = useContext(RobotContext);

  const { cameraState } = useContext(CameraState);

  const [showDropdown, setShowDropdown] = useState<boolean>(false);
  const [zoneState, setZoneState] = useState<string>("normal");
  const [transparency_lv, settransparency_lv] = useState<number>(0);

  //const [tornado, settornado] = useState<boolean>(false);

  const items: MenuProps["items"] = [
    {
      label: "Walk To",
      disabled: autopilot,
      key: "5",
      onClick: () => {
        console.log("Walk to X: " + position.x + " Y:" + position.y);
        setShowDropdown(false);
      },
    },
    {
      label: "More Information",
      key: "6",
      onClick: () => {
        console.log("INFORMATION ABOUT OBJECT");
        setShowDropdown(false);
      },
    },
    {
      label: "request Zone data",
      key: "6",
      onClick: () => {
        console.log("DOWNLOAD DATA ZONE!!!!!!!!!!!!!!");
        setShowDropdown(false);
        setZoneState("request");
        settransparency_lv(0.5);
      },
    },
    {
      label: "reset",
      key: "6",
      onClick: () => {
        console.log("reset");
        setShowDropdown(false);
        setZoneState("normal");
        settransparency_lv(0.0);
      },
    },
  ];

  return (
    <group>
      {showDropdown ? (
        <Html center position={[position.x, position.y + 1, position.z]}>
          <Dropdown menu={{ items }} trigger={["click"]}>
            <Button
              type="text"
              style={{
                background: "rgba(0,0,0,0.8)",
                color: "white",
                padding: "2px 10px 2px 10px",
                borderRadius: 10,
                userSelect: "none",
              }}
            >
              Zone
              <RightOutlined />
            </Button>
          </Dropdown>
        </Html>
      ) : (
        <Html></Html>
      )}
      <mesh
        position={[position.x, position.y, position.z]}
        rotation={rot3(Math.PI / 2, 0, 0)}
        scale={2}
        onClick={(event) => {
          if (cameraState.position === "God") {
            setShowDropdown(!showDropdown);
          }
        }}
      >
        <planeGeometry args={[30, 30, 100, 100]} />
        <meshStandardMaterial
          color={"red"}
          side={DoubleSide}
          depthWrite={false}
          transparent={true}
          opacity={transparency_lv}
        />
      </mesh>
    </group>
  );
};
