import { useFrame } from "@react-three/fiber";
import { forwardRef, useRef, useState } from "react";
import { rot3, vec3 } from "../../../functions/Map";
import { LidarObject } from "../../../models/Data";
import Alien from "./sensed-objects/AlienObject";
import Stone from "./sensed-objects/Stone";
import moment from "moment";
interface Props {
  replay: boolean;
}

const LidarObjects = forwardRef(({ replay }: Props, ref: any) => {
  //Array of objects to be mapped to the canvas
  const [objectsOnCanvas, setObjectsOnCanvas] = useState<any[]>([]);

  const prevTime = useRef<number>(moment().unix());
  useFrame(() => {
    if (!ref) return;
    if (moment().unix() - prevTime.current < 0.01) return;
    prevTime.current = moment().unix();

    //The list of sensed objects, this info comes from the situation report group
    const tempLidarObjects = ref.current.lidarObjects as LidarObject[];

    //For loop to loop through all the objects and add them to the object array
    let tempObjects = [];
    for (let i = 0; i < tempLidarObjects.length; i++) {
      const currentObject = tempLidarObjects[i];
      const id = parseInt(currentObject.id);

      //Conditions to see what kind of object that is sensed
      if (currentObject.type === "stone") {
        tempObjects.push(
          <Stone
            id={id}
            key={10001 + id}
            position={vec3(currentObject.data.x, -1, currentObject.data.y)}
            replay={replay}
          />
        );
      }
    }
    setObjectsOnCanvas(tempObjects);
  });

  //Returning a group of objects
  //The group contains the lidar's sensed objects
  return <group key={10001}>{objectsOnCanvas.map((object) => object)}</group>;
});

export default LidarObjects;
