import { useFrame } from "@react-three/fiber";
import moment from "moment";
import { forwardRef, useRef, useState } from "react";
import { vec3 } from "../../../functions/Map";
import {
  SeismicSensor,
  TemperatureSensor,
  WindSensor,
} from "../../../models/Data";
import GeneralSensor from "./sensed-objects/GeneralSensor";

interface Props {
  replay: boolean;
}

const SensorObjects = forwardRef(({ replay }: Props, ref: any) => {
  //Array of objects to be mapped to the canvas
  const [objectsOnCanvas, setObjectsOnCanvas] = useState<any[]>([]);

  const prevTime = useRef<number>(moment().unix());

  useFrame(() => {
    if (moment().unix() - prevTime.current < 0.2) return;
    //The list of sensed objects, this info comes from the situation report group
    const tempLidarObjects = ref.current.sensors as (
      | WindSensor
      | TemperatureSensor
      | SeismicSensor
    )[];

    //For loop to loop through all the objects and add them to the object array
    let tempObjects = [];
    for (let i = 0; i < tempLidarObjects.length; i++) {
      const currentObject = tempLidarObjects[i];
      const id = currentObject.id;

      //TODO: CHECK TYPES
      if ("wind_vec" in currentObject)
        tempObjects.push(
          <GeneralSensor
            id={id}
            key={20001 + i}
            position={vec3(currentObject.pos.x, -1, currentObject.pos.y)}
            type="Wind"
            replay={replay}
          />
        );
      else if ("temp" in currentObject)
        tempObjects.push(
          <GeneralSensor
            id={id}
            key={20001 + i}
            position={vec3(currentObject.pos.x, -1, currentObject.pos.y)}
            type="Temperature"
            replay={replay}
          />
        );
      else if ("shake_val" in currentObject)
        tempObjects.push(
          <GeneralSensor
            id={id}
            key={20001 + i}
            position={vec3(currentObject.pos.x, -1, currentObject.pos.y)}
            type="Seismic"
            replay={replay}
          />
        );
    }
    if (tempObjects.length > 0) {
      setObjectsOnCanvas(tempObjects);
      prevTime.current = moment().unix();
    }
  });

  //Returning a group of objects
  //The group contains the lidar's sensed objects
  return (
    <group key={20001}>{[...objectsOnCanvas].map((object) => object)}</group>
  );
});

export default SensorObjects;
