import { forwardRef, useContext, useEffect, useState } from "react";
import * as THREE from "three";
import { Position2 } from "../../../../models/Data";
import { Line } from "@react-three/drei";
import { vec3 } from "../../../../functions/Map";
import RobotContext from "../../../../state/Robot";
import FullScreenOverlayComponenetsContext from "../../../../state/FullScreenOverlayLayout";

const CurrentPath = forwardRef((props, ref: any) => {
  const [Path, setPath] = useState<Position2[]>([]);
  const { cameraState } = useContext(RobotContext);
  const { togglePath, settogglePath } = useContext(
    FullScreenOverlayComponenetsContext
  );

  // This useEffect checks in an interval if a new path has arrived from motionplanning, if it has then re-render component with setPath
  useEffect(() => {
    const interval = setInterval(() => {
      if (ref.current.motionPath !== Path) {
        setPath(ref.current.motionPath);
        console.log(
          "The Motion path has been updated by motion planning: ",
          ref.current.motionPath
        );
      }
    }, 1000);

    return () => clearInterval(interval);
  }, [ref, Path]);

  // Recalculate the path
  if (Path.length !== 0) {
    try {
      const curve = new THREE.CatmullRomCurve3(
        Path.map((pos: Position2) => {
          return vec3(pos.x, -0.5, pos.y);
        })
      );
      var vertices = [] as any;
      curve.getPoints(25).forEach((e) => {
        vertices.push(e.x, e.y, e.z);
      });
    } catch (e) {
      console.log(e);
    }
  }
  // If the path doesnt contain any points then dont try to draw a line, otherwise draw it.
  if (Path.length === 0) {
    return <mesh></mesh>;
  } else {
    return (
      <mesh>
        <Line
          points={vertices}
          color={"green"}
          lineWidth={cameraState.position !== "Robot" ? 2 : 16}
          transparent={true}
          opacity={togglePath ? 0 : 1}
          visible={!togglePath}
          depthWrite={false}
          depthTest={true}
        />
      </mesh>
    );
  }
});

export default CurrentPath;
