import { useFrame } from "@react-three/fiber";
import { forwardRef, useRef, useState } from "react";
import { generateInteractionPlane } from "../../../../functions/Map";
import { Position2 } from "../../../../models/Data";

interface Props {
  setHoveredCoordinate: (position: Position2) => void;
}

const InteractionPlane = forwardRef(
  ({ setHoveredCoordinate }: Props, ref: any) => {
    //State for the satellite image
    const [satelliteImage, setSatelliteImage] = useState<string>("");

    // This reference gives us direct access to the THREE.Mesh object
    const width = useRef(860);
    const height = useRef(882);

    //When the image updates we also update the state
    useFrame(() => {
      if (ref.current.satelitteImage !== satelliteImage) {
        setSatelliteImage(ref.current.satelitteImage);
        //Here the width and height of the image is calculated
        const img = new Image();
        img.src = ref.current.satelitteImage;
        img.onload = () => {
          width.current =
            img.width *
            ref.current.generalInformation.satelliteImageScaleFactor;
          height.current =
            img.height *
            ref.current.generalInformation.satelliteImageScaleFactor;
        };
      }
    });
    return (
      <group key={1001}>
        {generateInteractionPlane(
          width.current,
          height.current,
          setHoveredCoordinate
        )}
      </group>
    );
  }
);

export default InteractionPlane;
