import { forwardRef, useContext, useEffect, useState } from "react";
import * as THREE from "three";
import { Position2 } from "../../../../models/Data";
import { Line } from "@react-three/drei";
import { vec3, vec2 } from "../../../../functions/Map";
import RobotContext from "../../../../state/Robot";
import { useRef } from "react";
import { useFrame } from "@react-three/fiber";
import FullScreenOverlayComponenetsContext from "../../../../state/FullScreenOverlayLayout";

const RobotPath = forwardRef((props, ref: any) => {
  const [Path, setPath] = useState<Position2[]>([]);
  const [tempPath, setTempPath] = useState<Position2[]>(ref.current.motionPath);
  const { cameraState } = useContext(RobotContext);
  const { togglePathhistory } = useContext(FullScreenOverlayComponenetsContext);

  //distance is used to calculate if we need to add a new point on the path
  var distance = 0 as number;
  //updatePath is used to update the current historyPath so it reaches the robot after a set distance
  const updatePath = useRef(Path);
  //vertices includes all points on the path
  var vertices = [] as any;

  useFrame(() => {
    // check if the position is not undefined
    if (ref.current.robot.pos.x === undefined) {
      return;
    }
    if (ref.current.robot.pos.y === undefined) {
      return;
    }
    var tempX = ref.current.robot.pos.x;
    var tempY = ref.current.robot.pos.y;
    if (Path.length === 0) {
      setPath([{ x: tempX, y: tempY }]);
    } else if (tempPath !== ref.current.motionPath) {
      setPath([]);
      updatePath.current = [];
      setTempPath(ref.current.motionPath);
    } else {
      //eucliden distance between last added point and robot current pos
      distance = Math.sqrt(
        Math.pow(Path[Path.length - 1].x - tempX, 2) +
          Math.pow(Path[Path.length - 1].y - tempY, 2)
      );
      if (distance >= 2) {
        updatePath.current.push({ x: tempX, y: tempY });
        setPath([...updatePath.current]);
      }
    }
  });

  //recalculate the path every time (might change this in the future for better performance)
  if (Path.length >= 2) {
    var curve = new THREE.CatmullRomCurve3(
      Path.map((pos: Position2) => {
        return vec3(pos.x, -0.5, pos.y);
      })
    );

    curve.getPoints(25).forEach((e) => {
      vertices.push(e.x, e.y, e.z);
    });
  }
  // Return a Historypath if we have enough points on the path
  if (Path.length === 0 || Path.length === 1) {
    return <mesh></mesh>;
  } else {
    return (
      <mesh>
        <Line
          points={vertices}
          color={"red"}
          lineWidth={cameraState.position !== "Robot" ? 2 : 16}
          transparent={true}
          opacity={1}
          visible={!togglePathhistory ? true : false}
          depthWrite={false}
          depthTest={true}
        />
      </mesh>
    );
  }
});

export default RobotPath;
