import { useFrame, useLoader } from "@react-three/fiber";
import { TextureLoader } from "three";
import { forwardRef, useRef, useState } from "react";
import rocky from "../../../textures/rock.jpg";

const SatellitePlane = forwardRef((props, ref: any) => {
  //State for the satellite image
  const [satelliteImage, setSatelliteImage] = useState<string>("");

  // This reference gives us direct access to the THREE.Mesh object
  const mesh = useRef();
  const width = useRef(860);
  const height = useRef(882);

  //When the image updates we also update the state
  useFrame(() => {
    if (ref.current.satelitteImage !== satelliteImage) {
      setSatelliteImage(ref.current.satelitteImage);
      //Here the width and height of the image is calculated
      const img = new Image();
      img.src = ref.current.satelitteImage;
      img.onload = () => {
        width.current =
          img.width * ref.current.generalInformation.satelliteImageScaleFactor;
        height.current =
          img.height * ref.current.generalInformation.satelliteImageScaleFactor;
      };
    }
  });

  //Here the image is loaded into a texture
  const texture = useLoader(
    TextureLoader,
    satelliteImage ? satelliteImage : rocky
  );

  //This returns a plane with the satellite image as texture
  return (
    <mesh
      receiveShadow
      position={[0, 0, 0]}
      ref={mesh.current}
      rotation={[Math.PI / 2, 0, 0]}
      scale={[1, 1, 1]}
      key={5001}
    >
      <meshStandardMaterial key={5002} attach={"material"} map={texture} />
      <planeGeometry key={5003} args={[width.current, height.current, 1, 1]} />
    </mesh>
  );
});

export default SatellitePlane;
