import { useRef } from "react";
import { Vector3 } from "three";
import { forwardRef, useState } from "react";
import { DoubleSide } from "three";
import { useFrame } from "@react-three/fiber";
import { vec3, vec2 } from "../../../../functions/Map";
interface Props {
  position: Vector3;
}

const ShadowPlane = forwardRef((props, ref: any) => {
  const mesh = useRef();
  const [shadowFrontierX, setshadowFrontierX] = useState<number>(1);
  const [shadowFrontierY, setshadowFrontierY] = useState<number>(1);
  const [shadowFrontierR, setshadowFrontierR] = useState<number>(1);

  //When the map updates we also update the the shadow zone
  useFrame(() => {
    if (
      ref.current.generalInformation.shadowFrontierX !== shadowFrontierX ||
      ref.current.generalInformation.shadowFrontierY !== shadowFrontierY ||
      ref.current.generalInformation.shadowFrontierR !== shadowFrontierR
    ) {
      setshadowFrontierX(ref.current.generalInformation.shadowFrontierX);
      setshadowFrontierY(ref.current.generalInformation.shadowFrontierY);
      setshadowFrontierR(ref.current.generalInformation.shadowFrontierR);
    }
  });
  //console.log("shadowR***********1");
  //console.log(shadowFrontierR);
  //console.log("shadowR************2");
  //console.log(shadowFrontierY);
  //console.log(shadowFrontierX);
  //console.log("shadowYX************3");
  var offset = 6000;
  var centerVec = vec3(0, -offset / 2, -2);
  var rotatedVec = vec3(
    centerVec.x * Math.cos((shadowFrontierR * Math.PI) / 180) -
      centerVec.y * Math.sin((shadowFrontierR * Math.PI) / 180),
    centerVec.x * Math.sin((shadowFrontierR * Math.PI) / 180) +
      centerVec.y * Math.cos((shadowFrontierR * Math.PI) / 180),
    centerVec.z
  );

  return (
    <mesh
      castShadow
      position={[
        shadowFrontierX + rotatedVec.x,
        rotatedVec.z,
        shadowFrontierY + rotatedVec.y,
      ]}
      ref={mesh.current}
      rotation={[Math.PI / 2, 0, (shadowFrontierR * Math.PI) / 180]}
      scale={[1, 1, 1]}
      key={4001}
    >
      <planeGeometry key={4002} args={[4000, offset, 1, 1]} />
      <meshStandardMaterial
        color={"green"}
        key={4003}
        transparent={true}
        opacity={0}
        depthWrite={false}
        side={DoubleSide}
      />
    </mesh>
  );
});

export default ShadowPlane;
