import { Vector3 } from "three";
import { useContext, useState } from "react";
import RobotContext from "../../../../../state/Robot";
import { vec2 } from "../../../../../functions/Map";
import { CameraState, Position } from "../../../../../models/Map";
import InstructionContext from "../../../../../state/InstructionCon";
import { Position2 } from "../../../../../models/Data";

interface Props {
  position: Vector3;
  setHoveredCoordinate: (position: Position2) => void;
}

const GridSquare = ({ position, setHoveredCoordinate }: Props) => {
  //Importing the camera state to be able to update it after a position has been selected
  //The setSelectedGrid is used to select a grid that the object should be moved to
  //The setMoveObjectMode is used to deside what components to show on the overlay
  const { setSelectedGrid, setInteractionMode, setCameraState } =
    useContext(RobotContext);

  //Current index is the index of the current instruction
  //It is needed together with addInstruction
  const { current_index, currentObjectId, setCurrentIndex, addInstruction } =
    useContext(InstructionContext);

  //This boolean is used to know if a grid is selected
  //If it is the color of it will be red and the hover effect will stop
  const [selected, setSelected] = useState(false);

  //This boolean holds the information about if a grid is hovered or not
  const [hover, setHover] = useState(false);

  //Return a grid square with onHover and onClick actions
  return (
    <group>
      <mesh
        position={[position.x, -1.2, position.z]}
        rotation={[Math.PI / 2, 0, 0]}
        scale={[1, 1, 1]}
        onClick={() => {
          setSelectedGrid(undefined);
          setSelected(true);
          setInteractionMode("none");
          let newPosition = {} as Position;

          //If currentObjectId is -1 it means that this is a "walk to" instruction
          if (currentObjectId === -1) {
            newPosition = {
              object: "robot",
              position: vec2(position.x, position.z),
            };
          }

          //Otherwise this is a "move" instruction and we want to move the object
          // with the id equal to currentObjectId
          else {
            newPosition = {
              object: currentObjectId,
              position: vec2(position.x, position.z),
            };
          }

          const tempPosList: Position[] = [];
          tempPosList.push(newPosition);
          setCurrentIndex(current_index + 1);
          addInstruction(current_index, 10, tempPosList, "Go To");
          let tempCameraState = {} as CameraState;
          tempCameraState.target = "Robot";
          tempCameraState.zoom = 1.0;
          tempCameraState.position = "Robot";
          tempCameraState.sensorId = 0;
          setCameraState(tempCameraState);
        }}
        onPointerOver={(event) => {
          if (selected) return;
          setHover(true);
          setHoveredCoordinate({ x: position.x, y: position.z });
        }}
        onPointerOut={(event) => {
          if (selected) return;
          setHover(false);
        }}
      >
        <planeGeometry args={[6, 6, 1, 1]} />
        <meshStandardMaterial
          transparent={true}
          opacity={0.2}
          color={selected ? "red" : hover ? "blue" : "orange"}
          depthWrite={false}
          depthTest={true}
        />
      </mesh>
    </group>
  );
};

export default GridSquare;
