import { Html } from "@react-three/drei";
import Title from "antd/es/typography/Title";
import { MleElement, Position2 } from "../../../../../models/Data";
import { vec3 } from "../../../../../functions/Map";
import { useContext, useState } from "react";
import { Button } from "antd";
import { AiFillCaretDown } from "react-icons/ai";
import MapContext from "../../../../../state/Map";
import RobotContext from "../../../../../state/Robot";

interface Props {
  element: MleElement;
  gridWidth: number;
  gridHeight: number;
}

const MleBox = ({ element, gridWidth, gridHeight }: Props) => {
  const { interactionMode } = useContext(RobotContext);
  const { setMleModalIsOpen, setSelectedMLE } = useContext(MapContext);
  const [hover, setHover] = useState<boolean>(false);
  const [selected, setSelected] = useState<boolean>(false);

  return (
    <mesh
      position={vec3(element.position.x, -0.5, element.position.y)}
      rotation={[Math.PI / 2, 0, 0]}
      onClick={(event) => {
        event.stopPropagation();
        if (interactionMode === "none") {
          setMleModalIsOpen(true);
          setSelectedMLE(element);
        }
      }}
    >
      {selected ? (
        <Html
          as="div"
          occlude
          center
          position={[0, 0, 4]}
          distanceFactor={30}
          zIndexRange={[1, 0]}
        >
          <div
            style={{
              userSelect: "none",
              MozUserSelect: "none",
              WebkitUserSelect: "none",
              msUserSelect: "none",
              margin: 0,
              width: hover ? 300 : 100,
              height: 120,
              background: "rgba(246, 255, 0, 0.8)",
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              flexDirection: "column",
              transition: "0.3s",
              borderRadius: 15,
            }}
            onPointerEnter={() => setHover(true)}
            onPointerLeave={() => setHover(false)}
          >
            <div
              style={{
                display: "flex",
                justifyContent: "center",
                alignItems: "flex-end",
                flexDirection: "column",
                height: 10,
                opacity: hover ? 1 : 0,
                transition: "0.3s",
                width: "100%",
                margin: "0px 15px 0px 0px",
              }}
            >
              <Button
                type="primary"
                onClick={() => {
                  setSelected(false);
                  setSelectedMLE(undefined);
                }}
              >
                X
              </Button>
            </div>

            <Title
              style={{
                margin: hover ? 0 : "25px 0px 0px 0px",
                fontSize: hover ? 42 : 62,
              }}
            >
              !
            </Title>
            <Button
              type="text"
              onClick={() => {
                setSelected(false);
                setMleModalIsOpen(true);
                setSelectedMLE(element);
              }}
              style={{
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
                flexDirection: "column",
                height: 50,
                opacity: hover ? 1 : 0,
                transition: "0.0s",
              }}
            >
              Click for more information
              <AiFillCaretDown style={{ fontSize: 24 }} />
            </Button>
          </div>
        </Html>
      ) : (
        <></>
      )}

      <planeGeometry args={[gridWidth, gridHeight, 1, 1]} />
      <meshStandardMaterial
        color={"white"}
        transparent={true}
        opacity={0.25}
        depthWrite={false}
        depthTest={true}
      />
    </mesh>
  );
};

export default MleBox;
