import { useContext, useEffect, useRef, useState } from "react";
import { Vector2, Vector3 } from "three";
import RobotContext from "../../../../../state/Robot";
import { vec2, vec3 } from "../../../../../functions/Map";
import { Button, Dropdown, MenuProps } from "antd";
import { Html } from "@react-three/drei";
import { RightOutlined } from "@ant-design/icons";
import GridSquare from "./GridSquare";
import { CameraState } from "../../../../../models/Map";
import InstructionContext from "../../../../../state/InstructionCon";
import { Position2 } from "../../../../../models/Data";

interface Props {
  position: Vector3;
  setHoveredCoordinate: (position: Position2) => void;
}

const PlaneSquare = ({ position, setHoveredCoordinate }: Props) => {
  const {
    interactionMode,
    interestingAreas,
    selectedGrid,
    setSelectedPlaneSquare,
    setCameraState,
    setSelectedGrid,
    setInteractionMode,
  } = useContext(RobotContext);

  const { setCurrentObjectId } = useContext(InstructionContext);

  //This reference gives us direct access to the THREE.Mesh object
  const mesh = useRef();

  //com.
  const [selected, setSelected] = useState(false);
  const [hover, setHover] = useState(false);
  const [showGrid, setShowGrid] = useState<boolean>(false);

  useEffect(() => {
    setHover(false);
  }, [interactionMode, selectedGrid]);

  useEffect(() => {
    if (selectedGrid) {
      if (JSON.stringify(selectedGrid) === JSON.stringify(position))
        setShowGrid(true);
      else {
        setShowGrid(false);
      }
    } else {
      setShowGrid(false);
    }
  }, [selectedGrid, position]);

  useEffect(() => {
    let isArea = false;
    for (let i = 0; i < interestingAreas.length; i++) {
      const a = interestingAreas[i].position as Vector2;
      const b = vec2(position.x, position.z) as Vector2;
      if (JSON.stringify(a) === JSON.stringify(b)) {
        isArea = true;
        setSelected(true);
      }
    }
    if (!isArea) setSelected(false);
  }, [interestingAreas, position]);

  const walkToOnClick = () => {
    setCurrentObjectId(-1);
    setInteractionMode("selectSquare");
    let tempCameraState = {} as CameraState;
    tempCameraState.target = position;
    tempCameraState.zoom = 1.0;
    tempCameraState.sensorId = 0;
    tempCameraState.position = vec3(position.x, position.y - 70, position.z);
    setCameraState(tempCameraState);
    setSelectedGrid(position);
  };

  return (
    <group>
      <mesh
        receiveShadow
        position={position}
        ref={mesh.current}
        rotation={[Math.PI / 2, 0, 0]}
        scale={[1, 1, 1]}
        onClick={(e) => {
          if (interactionMode === "none") return;
          else if (interactionMode === "selectZone") {
            setSelectedPlaneSquare(position);
            walkToOnClick();
          } else if (interactionMode === "selectGrid") {
            setInteractionMode("selectSquare");
            let tempCameraState = {} as CameraState;
            tempCameraState.target = position;
            tempCameraState.zoom = 1.0;
            tempCameraState.sensorId = 0;
            tempCameraState.position = vec3(
              position.x,
              position.y - 70,
              position.z
            );
            setCameraState(tempCameraState);
            setSelectedGrid(position);
          }
        }}
        onPointerOver={(event) => {
          if (interactionMode === "none" || interactionMode === "selectSquare")
            return;
          setHoveredCoordinate({ x: position.x, y: position.z });
          setHover(true);
        }}
        onPointerOut={(event) => {
          if (interactionMode === "none" || interactionMode === "selectSquare")
            return;
          setHover(false);
        }}
      >
        <meshStandardMaterial
          color={selected ? "red" : hover ? "green" : "orange"}
          transparent={true}
          opacity={hover || selected ? 0.8 : 0.2}
          depthWrite={false}
          depthTest={true}
        />
        <planeGeometry args={[60, 60, 1, 1]} />
      </mesh>
      {showGrid ? (
        <group key={4000}>
          {Array(10)
            .fill(0)
            .map((_, rowIndex) =>
              Array(10)
                .fill(0)
                .map((_, colIndex) => {
                  const x = position.x + 6 * rowIndex - 27;
                  const z = position.z + 6 * colIndex - 27;
                  return (
                    <GridSquare
                      key={`${rowIndex}_${colIndex}`}
                      position={vec3(x, 0.9, z)}
                      setHoveredCoordinate={setHoveredCoordinate}
                    />
                  );
                })
            )}
          <gridHelper
            position={vec3(position.x, position.y - 0.025, position.z)}
            args={[60, 10, 0xff0000, "teal"]}
          />
        </group>
      ) : (
        <mesh></mesh>
      )}
    </group>
  );
};

export default PlaneSquare;
