import { Html } from "@react-three/drei";
import { CirclePlane } from "../sensed-objects/CirclePlane";
import { Rover } from "./Rover";
import { Arm1, Arm2, Arm3, Claw1, Claw2, Claw_lock } from "./Arm";
import { vec3 } from "../../../../functions/Map";
import { forwardRef, useRef } from "react";
import { useFrame } from "@react-three/fiber";

const RobotObject = forwardRef((props, ref: any) => {
  const robotRef = useRef<any>({});

  const robotArmref = useRef<any>({});

  useFrame(() => {
    //Update the robot ref
    robotRef.current.position.x = ref.current.robot.pos.x;
    robotRef.current.position.y = -0.6;
    robotRef.current.position.z = ref.current.robot.pos.y;
    robotRef.current.rotation.x = 0;
    robotRef.current.rotation.y = -ref.current.robot.pos.r;
    robotRef.current.rotation.z = Math.PI;

    robotRef.current.arm1 = ref.current.robotarm.arm1_jointAngle;

    robotRef.current.arm2 =
      ref.current.robotarm.arm2_jointAngle +
      ref.current.robotarm.arm1_jointAngle;

    robotRef.current.arm3 =
      ref.current.robotarm.arm3_jointAngle +
      ref.current.robotarm.arm2_jointAngle +
      ref.current.robotarm.arm1_jointAngle;
    robotRef.current.claw1 =
      (45 * Math.PI) / 180 +
      ref.current.robotarm.arm3_jointAngle +
      ref.current.robotarm.arm2_jointAngle +
      ref.current.robotarm.arm1_jointAngle;
    robotRef.current.claw2 =
      (-45 * Math.PI) / 180 +
      ref.current.robotarm.arm3_jointAngle +
      ref.current.robotarm.arm2_jointAngle +
      ref.current.robotarm.arm1_jointAngle;

    robotRef.current.claw_lock =
      (135 * Math.PI) / 180 +
      (-45 * Math.PI) / 180 +
      ref.current.robotarm.arm3_jointAngle +
      ref.current.robotarm.arm2_jointAngle +
      ref.current.robotarm.arm1_jointAngle;

    robotRef.current.claw_lock_bool = ref.current.robotarm.arm_opened;

    var arm_length = 3;

    robotRef.current.arm_length = arm_length;
    var offset = arm_length;

    var centerVec = vec3(0, offset / 2, 0);
    var rotx = (offset / 2) * Math.sin(robotRef.current.arm1);

    var rotatedVec = vec3(
      centerVec.x * Math.cos(robotRef.current.arm1) -
        centerVec.y * Math.sin(robotRef.current.arm1),
      centerVec.x * Math.sin(robotRef.current.arm1) +
        centerVec.y * Math.cos(robotRef.current.arm1),
      centerVec.z
    );
    robotRef.current.arm1pos = [rotx, 0.5, rotatedVec.y];

    var offset2 = arm_length;

    var centerVec2 = vec3(0, offset2 / 2, 0);
    var rotx2 = (offset2 / 2) * Math.sin(robotRef.current.arm2);

    var rotatedVec2 = vec3(
      centerVec2.x * Math.cos(robotRef.current.arm2) -
        centerVec2.y * Math.sin(robotRef.current.arm2),
      centerVec2.x * Math.sin(robotRef.current.arm2) +
        centerVec2.y * Math.cos(robotRef.current.arm2),
      centerVec2.z
    );
    //robotRef.current.arm2pos =[   rotx2  ,0.5 ,        rotatedVec.y] ;

    robotRef.current.arm2pos = [
      rotx2 + rotx * 2,
      0.5,
      rotatedVec2.y + rotatedVec.y * 2,
    ];

    var offset3 = arm_length;

    var centerVec3 = vec3(0, offset3 / 2, 0);
    var rotx3 = (offset3 / 2) * Math.sin(robotRef.current.arm3);

    var rotatedVec3 = vec3(
      centerVec3.x * Math.cos(robotRef.current.arm3) -
        centerVec3.y * Math.sin(robotRef.current.arm3),
      centerVec3.x * Math.sin(robotRef.current.arm3) +
        centerVec3.y * Math.cos(robotRef.current.arm3),
      centerVec3.z
    );

    robotRef.current.arm3pos = [
      rotx3 + rotx * 2 + rotx2 * 2,
      0.5,
      rotatedVec3.y + rotatedVec.y * 2 + rotatedVec2.y * 2,
    ];

    //Claw 1 *********************************************************************************************************************
    var claw_length = 2;
    robotRef.current.claw_length = claw_length;
    var offset4 = claw_length;
    var centerVec4 = vec3(0, offset4 / 2, 0);

    var rotx4 = (offset4 / 2) * Math.sin(robotRef.current.claw1);
    var rotatedVec4 = vec3(
      centerVec4.x * Math.cos(robotRef.current.claw1) -
        centerVec4.y * Math.sin(robotRef.current.claw1),
      centerVec4.x * Math.sin(robotRef.current.claw1) +
        centerVec4.y * Math.cos(robotRef.current.claw1),
      centerVec4.z
    );
    robotRef.current.arm4pos = [
      rotx4 + rotx3 * 2 + rotx * 2 + rotx2 * 2,
      0.5,
      rotatedVec4.y + rotatedVec3.y * 2 + rotatedVec.y * 2 + rotatedVec2.y * 2,
    ];
    //Claw 2 *********************************************************************************************************************
    var offset5 = claw_length;
    var centerVec5 = vec3(0, offset5 / 2, 0);
    var rotx5 = (offset5 / 2) * Math.sin(robotRef.current.claw2);
    var rotatedVec5 = vec3(
      centerVec5.x * Math.cos(robotRef.current.claw2) -
        centerVec5.y * Math.sin(robotRef.current.claw2),
      centerVec5.x * Math.sin(robotRef.current.claw2) +
        centerVec5.y * Math.cos(robotRef.current.claw2),
      centerVec5.z
    );
    robotRef.current.arm5pos = [
      rotx5 + rotx3 * 2 + rotx * 2 + rotx2 * 2,
      0.5,
      rotatedVec5.y + rotatedVec3.y * 2 + rotatedVec.y * 2 + rotatedVec2.y * 2,
    ];
    //Claw LOCK *****************************************************************************************************************
    var offset6 = claw_length + 0.8;
    var centerVec6 = vec3(0, offset6 / 2, 0);
    var rotx6 = (offset6 / 2) * Math.sin(robotRef.current.claw_lock);
    var rotatedVec6 = vec3(
      centerVec6.x * Math.cos(robotRef.current.claw_lock) -
        centerVec6.y * Math.sin(robotRef.current.claw_lock),
      centerVec6.x * Math.sin(robotRef.current.claw_lock) +
        centerVec6.y * Math.cos(robotRef.current.claw_lock),
      centerVec6.z
    );
    robotRef.current.claw_lock_pos = [
      rotx6 + rotx5 * 2 + rotx3 * 2 + rotx * 2 + rotx2 * 2,
      0.5,
      rotatedVec6.y +
        rotatedVec5.y * 2 +
        rotatedVec3.y * 2 +
        rotatedVec.y * 2 +
        rotatedVec2.y * 2,
    ];
  });

  //Returns a robot object that contains a HTML label, the NASA rover model
  //and a circle plane that shows the lidars scanning radius
  return (
    <group key={1} ref={robotRef}>
      <Html center zIndexRange={[2, 1]} key={2}>
        <p
          style={{
            background: "rgba(0,0,0,0.8)",
            color: "white",
            padding: "2px 10px 2px 10px",
            borderRadius: 10,
            userSelect: "none",
          }}
        >
          Rover
        </p>
      </Html>
      <Arm1 key={-133} rot={robotRef.current.arm1} reff={robotRef} />
      <Arm2 key={-134} rot={robotRef.current.arm2} reff={robotRef} />
      <Arm3 key={-135} rot={robotRef.current.arm2} reff={robotRef} />
      <Claw1 key={-136} rot={robotRef.current.claw1} reff={robotRef} />

      <Claw2 key={-137} rot={robotRef.current.claw1} reff={robotRef} />
      <Claw_lock key={-138} rot={robotRef.current.Claw_lock} reff={robotRef} />
      <Rover key={3} />
      <CirclePlane
        key={4}
        color={"yellow"}
        position={vec3(0, 0.3, 0)}
        radius={30}
      />
    </group>
  );
});

export default RobotObject;
