import { useGLTF } from "@react-three/drei";

//This file contains the rover model
//The model was downloaded from NASA

export const Rover = (props: any) => {
  const { nodes, materials } = useGLTF("/Perseverance.glb");

  return (
    <group {...props} dispose={null}>
      <mesh
        geometry={nodes.hazcams_rear_wiring.geometry}
        material={materials.grey_brushed}
        position={[0.47, 0.78, -1.14]}
        rotation={props.rotation}
      />
      <mesh
        geometry={nodes.microphones.geometry}
        material={materials.grey_brushed}
        position={[0.61, 1.01, -0.3]}
      />
      <group
        position={[-0.01, 0.96, 1.12]}
        rotation={[-Math.PI, 0, 0]}
        scale={0.03}
      >
        <mesh
          geometry={nodes.Cylinder005.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cylinder005_1.geometry}
          material={materials.gunmetal_dark}
        />
      </group>
      <group position={[0.61, 0.71, 0.83]}>
        <mesh geometry={nodes.Cube026.geometry} material={materials.aluminum} />
        <mesh
          geometry={nodes.Cube026_1.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube026_2.geometry}
          material={materials.grey_brushed}
        />
      </group>
      <group position={[-0.61, 0.72, 0.83]}>
        <mesh geometry={nodes.Cube027.geometry} material={materials.aluminum} />
        <mesh
          geometry={nodes.Cube027_1.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube027_2.geometry}
          material={materials.grey_brushed}
        />
      </group>
      <group position={[-0.56, 1.21, 0.72]}>
        <mesh
          geometry={nodes["10453412-101_B_3961624036"].geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624036_1"].geometry}
          material={materials.gunmetal}
        />
      </group>
      <group position={[-0.39, 1.33, -0.6]}>
        <mesh geometry={nodes.Cube028.geometry} material={materials.aluminum} />
        <mesh
          geometry={nodes.Cube028_1.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube028_2.geometry}
          material={materials["glass lens"]}
        />
      </group>
      <mesh
        geometry={nodes.arm_01_joint.geometry}
        material={materials.aluminum}
        position={[-0.41, 0.66, -0.23]}
      >
        <mesh
          geometry={nodes.arm_01_pivot.geometry}
          material={materials.transparent}
          position={[-0.01, 0, 0.04]}
          rotation={[Math.PI / 2, 0, 0]}
        >
          <mesh
            geometry={nodes.arm_01.geometry}
            material={materials.gunmetal}
            position={[-0.07, -0.05, 0]}
            rotation={[Math.PI / 2, Math.PI / 2, 0]}
            scale={0}
          />
        </mesh>
      </mesh>
      <mesh
        geometry={nodes.arm_02_joint.geometry}
        material={materials.aluminum}
        position={[0.02, 0.7, -0.26]}
      >
        <mesh
          geometry={nodes.arm_02_pivot.geometry}
          material={materials.transparent}
          position={[0, 0, 0.11]}
          rotation={[Math.PI / 2, 0, Math.PI]}
        >
          <group
            position={[-0.08, 0.09, 0.01]}
            rotation={[Math.PI / 2, 0, -Math.PI]}
          >
            <mesh
              geometry={
                nodes[
                  "10463723-1_6-MHDS_BELLY_PAN_A1-MIA,_MHDS_BELLY_PAN_655754007"
                ].geometry
              }
              material={materials.gunmetal}
            />
            <mesh
              geometry={
                nodes[
                  "10463723-1_6-MHDS_BELLY_PAN_A1-MIA,_MHDS_BELLY_PAN_655754007_1"
                ].geometry
              }
              material={materials.iron}
            />
          </group>
          <mesh
            geometry={nodes.arm_02001.geometry}
            material={materials.iron}
            position={[-0.08, 0.09, 0.01]}
            rotation={[Math.PI / 2, 0, -Math.PI]}
          />
        </mesh>
      </mesh>
      <mesh
        geometry={nodes.pan_end_cover.geometry}
        material={materials.aluminum}
        position={[-0.19, 0.67, -0.84]}
      />
      <mesh
        geometry={nodes.calibration_target_bracket.geometry}
        material={materials.gunmetal_dark}
        position={[-0.02, 1.16, 0.08]}
      />
      <group position={[0, 0.26, -0.03]}>
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223001"].geometry
          }
          material={materials.aluminum_black}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223001_1"].geometry
          }
          material={materials.aluminum}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223001_2"].geometry
          }
          material={materials.hub}
        />
      </group>
      <group
        position={[0.45, 0.91, 1.18]}
        rotation={[-Math.PI, -1.57, 0]}
        scale={0.03}
      >
        <mesh
          geometry={nodes.Cylinder013.geometry}
          material={materials.gunmetal_dark}
        />
        <mesh
          geometry={nodes.Cylinder013_1.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cylinder013_2.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cylinder013_3.geometry}
          material={materials.foil_orange}
        />
        <group position={[-4.95, 2.75, 2.32]} rotation={[0, 0, -0.28]}>
          <mesh
            geometry={nodes.Cylinder014.geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes.Cylinder014_1.geometry}
            material={materials.gunmetal_dark}
          />
          <mesh
            geometry={nodes.Cylinder014_2.geometry}
            material={materials.mars_2020_07}
          />
          <mesh
            geometry={nodes.Cylinder014_3.geometry}
            material={materials.gunmetal}
          />
          <mesh
            geometry={nodes.Cylinder014_4.geometry}
            material={materials.arm_graphics}
          />
          <mesh
            geometry={nodes.Cylinder014_5.geometry}
            material={materials.mars_2020_02_n}
          />
          <mesh
            geometry={nodes.Cylinder014_6.geometry}
            material={materials.bronze}
          />
          <group position={[-23.49, -6.82, 0.65]} rotation={[0, 0, -1.26]}>
            <mesh
              geometry={nodes.Cylinder041.geometry}
              material={materials.gunmetal_dark}
            />
            <mesh
              geometry={nodes.Cylinder041_1.geometry}
              material={materials.paint_white_base}
            />
            <mesh
              geometry={nodes.Cylinder041_2.geometry}
              material={materials.mars_2020_07}
            />
            <mesh
              geometry={nodes.Cylinder041_3.geometry}
              material={materials.gunmetal}
            />
            <mesh
              geometry={nodes.Cylinder041_4.geometry}
              material={materials.foil_orange}
            />
            <mesh
              geometry={nodes.Cylinder041_5.geometry}
              material={materials.arm_graphics}
            />
            <mesh
              geometry={nodes.Cylinder041_6.geometry}
              material={materials.mars_2020_02_n}
            />
            <mesh
              geometry={nodes.Cylinder041_7.geometry}
              material={materials.bronze}
            />
            <group position={[22.47, -0.72, 0.57]} rotation={[0, 0, 1.54]}>
              <mesh
                geometry={nodes.Cylinder018.geometry}
                material={materials.gunmetal}
              />
              <mesh
                geometry={nodes.Cylinder018_1.geometry}
                material={materials.gunmetal_dark}
              />
              <group
                position={[5.24, -4.55, 1.8]}
                rotation={[-3.14, -1.41, 0]}
                scale={29.85}
              >
                <mesh
                  geometry={nodes.Cylinder015.geometry}
                  material={materials.gunmetal}
                />
                <mesh
                  geometry={nodes.Cylinder015_1.geometry}
                  material={materials.gunmetal_dark}
                />
                <mesh
                  geometry={nodes.Cylinder015_2.geometry}
                  material={materials.Material}
                />
                <mesh
                  geometry={nodes.Cylinder015_3.geometry}
                  material={materials.foil_orange}
                />
                <mesh
                  geometry={nodes.Cylinder015_4.geometry}
                  material={materials.aluminum}
                />
                <mesh
                  geometry={nodes.Cylinder015_5.geometry}
                  material={materials.paint_white_base}
                />
                <mesh
                  geometry={nodes.Cylinder015_6.geometry}
                  material={materials.bronze}
                />
                <mesh
                  geometry={nodes.Cylinder015_7.geometry}
                  material={materials.mars_2020_07}
                />
                <mesh
                  geometry={nodes.Cylinder015_8.geometry}
                  material={materials.mars_2020_06}
                />
                <mesh
                  geometry={nodes.Cylinder015_9.geometry}
                  material={materials.arm_graphics}
                />
                <group position={[-0.03, 0.18, 0.23]}>
                  <mesh
                    geometry={nodes.Cylinder012.geometry}
                    material={materials.aluminum}
                  />
                  <mesh
                    geometry={nodes.Cylinder012_1.geometry}
                    material={materials.gunmetal}
                  />
                </group>
                <group
                  position={[0.29, 0.17, 0.17]}
                  rotation={[-Math.PI, 0.02, -Math.PI]}
                >
                  <mesh
                    geometry={nodes.Cylinder032.geometry}
                    material={materials.gunmetal}
                  />
                  <mesh
                    geometry={nodes.Cylinder032_1.geometry}
                    material={materials.glass_2}
                  />
                </group>
                <group
                  position={[0.33, 0.22, -0.09]}
                  rotation={[-Math.PI, 0.02, -Math.PI]}
                >
                  <mesh
                    geometry={nodes.Cylinder031.geometry}
                    material={materials.gunmetal}
                  />
                  <mesh
                    geometry={nodes.Cylinder031_1.geometry}
                    material={materials.glass_2}
                  />
                </group>
                <mesh
                  geometry={nodes.hinge.geometry}
                  material={materials.transparent}
                  position={[-0.32, 0.14, -0.04]}
                  rotation={[2.49, -1.37, 0.93]}
                >
                  <group rotation={[-1.41, -0.02, -1.69]}>
                    <mesh
                      geometry={nodes.Cylinder003.geometry}
                      material={materials.mars_2020_05}
                    />
                    <mesh
                      geometry={nodes.Cylinder003_1.geometry}
                      material={materials["glass lens"]}
                    />
                  </group>
                </mesh>
                <group position={[-0.24, 0.17, -0.04]}>
                  <mesh
                    geometry={nodes.Cylinder001.geometry}
                    material={materials.paint_white_base}
                  />
                  <mesh
                    geometry={nodes.Cylinder001_1.geometry}
                    material={materials.mars_2020_05}
                  />
                  <mesh
                    geometry={nodes.Cylinder001_2.geometry}
                    material={materials.glass_2}
                  />
                </group>
                <group position={[0.23, 0.18, 0.05]}>
                  <mesh
                    geometry={nodes.Cylinder008.geometry}
                    material={materials.iron}
                  />
                  <mesh
                    geometry={nodes.Cylinder008_1.geometry}
                    material={materials.gunmetal_dark}
                  />
                  <mesh
                    geometry={nodes.Cylinder008_2.geometry}
                    material={materials.glass_2}
                  />
                  <mesh
                    geometry={nodes.Cylinder008_3.geometry}
                    material={materials.gunmetal}
                  />
                </group>
                <group position={[0.23, 0.18, 0.05]}>
                  <mesh
                    geometry={nodes.Cylinder021.geometry}
                    material={materials.gunmetal}
                  />
                  <mesh
                    geometry={nodes.Cylinder021_1.geometry}
                    material={materials.gunmetal_dark}
                  />
                </group>
                <mesh
                  geometry={nodes.turret_obj006.geometry}
                  material={materials.gunmetal_dark}
                  position={[0.23, 0.18, 0.05]}
                />
                <group position={[0.23, 0.18, 0.05]}>
                  <mesh
                    geometry={nodes.Cylinder023.geometry}
                    material={materials.gunmetal_dark}
                  />
                  <mesh
                    geometry={nodes.Cylinder023_1.geometry}
                    material={materials.aluminum}
                  />
                  <mesh
                    geometry={nodes.Cylinder023_2.geometry}
                    material={materials.gunmetal}
                  />
                </group>
                <group position={[0.31, 0.19, -0.06]}>
                  <mesh
                    geometry={nodes.Cylinder009.geometry}
                    material={materials.gunmetal_dark}
                  />
                  <mesh
                    geometry={nodes.Cylinder009_1.geometry}
                    material={materials.iron}
                  />
                  <mesh
                    geometry={nodes.Cylinder009_2.geometry}
                    material={materials.glass_2}
                  />
                  <mesh
                    geometry={nodes.Cylinder009_3.geometry}
                    material={materials.gunmetal}
                  />
                </group>
              </group>
            </group>
          </group>
        </group>
      </group>
      <group position={[-0.5, 1.64, -1.08]} scale={[0.08, 0.09, 0.08]}>
        <mesh
          geometry={nodes.Cylinder.geometry}
          material={materials.black_krinkle}
        />
        <mesh
          geometry={nodes.Cylinder_1.geometry}
          material={materials.gunmetal_dark}
        />
      </group>
      <group position={[-0.63, 1.24, 0.61]}>
        <mesh geometry={nodes.Cube002.geometry} material={materials.bronze} />
        <mesh
          geometry={nodes.Cube002_1.geometry}
          material={materials.mars_2020_02_n}
        />
      </group>
      <group position={[-0.08, 0.72, 0.97]}>
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014"
            ].geometry
          }
          material={materials.aluminum_black}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014_1"
            ].geometry
          }
          material={materials.paint_white_base}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014_2"
            ].geometry
          }
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014_3"
            ].geometry
          }
          material={materials.aluminum}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014_4"
            ].geometry
          }
          material={materials.spring}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59014_5"
            ].geometry
          }
          material={materials.mars_2020_06_brass2}
        />
      </group>
      <group position={[0.47, 0.78, -1.14]}>
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004"].geometry
          }
          material={materials.aluminum_black}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_1"].geometry
          }
          material={materials.mars_2020_06_brass2}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_2"].geometry
          }
          material={materials.grey_brushed}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_3"].geometry
          }
          material={materials.aluminum}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_4"].geometry
          }
          material={materials.paint_white_base}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_5"].geometry
          }
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={
            nodes["10461523-101_A-REAR_-Y_HAZCAM_BRACKET_12976004_6"].geometry
          }
          material={materials.spring}
        />
      </group>
      <group
        position={[0.49, 1.51, -0.94]}
        rotation={[-Math.PI, 0, 0]}
        scale={0}
      >
        <mesh
          geometry={
            nodes["10450513-101_B-WAVEGUIDE,_RIGID,_RECTANGULAR_50248000"]
              .geometry
          }
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={
            nodes["10450513-101_B-WAVEGUIDE,_RIGID,_RECTANGULAR_50248000_1"]
              .geometry
          }
          material={materials.mars_2020_06_brass2}
        />
      </group>
      <group position={[-0.02, 1.16, 0.08]}>
        <mesh geometry={nodes.Cube029.geometry} material={materials.aluminum} />
        <mesh
          geometry={nodes.Cube029_1.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube029_2.geometry}
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={nodes.Cube029_3.geometry}
          material={materials.gunmetal_dark}
        />
      </group>
      <group position={[0.65, 0.78, 0.67]}>
        <mesh geometry={nodes.Cube003.geometry} material={materials.aluminum} />
        <mesh
          geometry={nodes.Cube003_1.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube003_2.geometry}
          material={materials.mars_2020_05}
        />
      </group>
      <group position={[0.42, 1.28, -0.39]}>
        <mesh
          geometry={
            nodes["10253070-104_B8-MSL_HGA_DISH_INTFC_115678013"].geometry
          }
          material={materials.aluminum}
        />
        <mesh
          geometry={
            nodes["10253070-104_B8-MSL_HGA_DISH_INTFC_115678013_1"].geometry
          }
          material={materials.mars_2020_01}
        />
        <mesh
          geometry={
            nodes["10253070-104_B8-MSL_HGA_DISH_INTFC_115678013_2"].geometry
          }
          material={materials.brass}
        />
        <mesh
          geometry={
            nodes["10253070-104_B8-MSL_HGA_DISH_INTFC_115678013_3"].geometry
          }
          material={materials.gunmetal}
        />
      </group>
      <mesh
        geometry={nodes.RIMFAX.geometry}
        material={materials.mars_2020_01}
        position={[0, 0.78, -1.06]}
      />
      <group position={[-0.02, 1.16, 0.08]}>
        <mesh geometry={nodes.Cube005.geometry} material={materials.gunmetal} />
        <mesh
          geometry={nodes.Cube005_1.geometry}
          material={materials.gunmetal_dark}
        />
        <mesh
          geometry={nodes.Cube005_2.geometry}
          material={materials.mars_2020_01}
        />
      </group>
      <group position={[-0.52, 1.92, 0.71]}>
        <mesh
          geometry={nodes["10453412-101_B_3961624048"].geometry}
          material={materials.mars_2020_02}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_1"].geometry}
          material={materials.mars_2020_03}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_2"].geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_3"].geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_4"].geometry}
          material={materials.bronze}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_5"].geometry}
          material={materials.mars_2020_06_brass2}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_6"].geometry}
          material={materials.mars_2020_01_n}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_7"].geometry}
          material={materials.aluminum_black}
        />
        <mesh
          geometry={nodes["10453412-101_B_3961624048_8"].geometry}
          material={materials.mars_2020_02_n}
        />
        <group position={[0.08, 0.21, 0.07]}>
          <mesh
            geometry={nodes["10453412-101_B_3961624003"].geometry}
            material={materials.gunmetal}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624003_1"].geometry}
            material={materials.mars_2020_02}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624003_2"].geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624003_3"].geometry}
            material={materials.glass_2}
          />
        </group>
        <group position={[-0.03, 0.14, 0]}>
          <mesh
            geometry={nodes["10453412-101_B_3961624002"].geometry}
            material={materials.mars_2020_02}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624002_1"].geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624002_2"].geometry}
            material={materials.mars_2020_06_brass2}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624002_3"].geometry}
            material={materials.aluminum_black}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624002_4"].geometry}
            material={materials.gunmetal}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624002_5"].geometry}
            material={materials.glass_2}
          />
        </group>
        <mesh
          geometry={nodes.microphones001.geometry}
          material={materials.grey_brushed}
          position={[0.02, 0.15, 0.12]}
        />
        <group position={[-0.03, 0.05, 0.05]}>
          <mesh
            geometry={nodes["10453412-101_B_3961624001"].geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_1"].geometry}
            material={materials.mars_2020_02}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_2"].geometry}
            material={materials.aluminum_black}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_3"].geometry}
            material={materials.mars_2020_05}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_4"].geometry}
            material={materials.glass_2}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_5"].geometry}
            material={materials.aluminum}
          />
          <mesh
            geometry={nodes["10453412-101_B_3961624001_6"].geometry}
            material={materials.mars_2020_06_brass2}
          />
        </group>
      </group>
      <group position={[0.51, 0.82, -1.22]} rotation={[-Math.PI / 4, -0.38, 0]}>
        <mesh
          geometry={nodes.Cube001.geometry}
          material={materials.aluminum_black}
        />
        <mesh
          geometry={nodes.Cube001_1.geometry}
          material={materials.mars_2020_04}
        />
      </group>
      <group position={[-0.51, 0.82, -1.22]} rotation={[2.36, -0.38, -Math.PI]}>
        <mesh
          geometry={nodes.Cube013.geometry}
          material={materials.aluminum_black}
        />
        <mesh
          geometry={nodes.Cube013_1.geometry}
          material={materials.mars_2020_04}
        />
      </group>
      <group position={[0, 1.16, -1.25]}>
        <mesh
          geometry={nodes.Cube009.geometry}
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={nodes.Cube009_1.geometry}
          material={materials.mars_2020_05_cooling_lines}
        />
        <mesh
          geometry={nodes.Cube009_2.geometry}
          material={materials.mars_2020_04}
        />
        <mesh
          geometry={nodes.Cube009_3.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube009_4.geometry}
          material={materials.mars_2020_06_brass2}
        />
        <mesh geometry={nodes.Cube009_5.geometry} material={materials.copper} />
        <mesh
          geometry={nodes.Cube009_6.geometry}
          material={materials.mars_2020_03}
        />
        <mesh
          geometry={nodes.Cube009_7.geometry}
          material={materials["array gold trim"]}
        />
        <mesh geometry={nodes.Cube009_8.geometry} material={materials.gold} />
        <mesh
          geometry={nodes.Cube009_9.geometry}
          material={materials.aluminum_black}
        />
        <mesh
          geometry={nodes.Cube009_10.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cube009_11.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube009_12.geometry}
          material={materials.gunmetal_dark}
        />
      </group>
      <group position={[0, 1.46, -0.91]}>
        <mesh
          geometry={nodes.Cube024.geometry}
          material={materials.mars_2020_04}
        />
        <mesh
          geometry={nodes.Cube024_1.geometry}
          material={materials.arm_graphics}
        />
        <mesh
          geometry={nodes.Cube024_2.geometry}
          material={materials.grey_brushed}
        />
        <mesh
          geometry={nodes.Cube024_3.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cube024_4.geometry}
          material={materials.glass_2}
        />
        <mesh
          geometry={nodes.Cube024_5.geometry}
          material={materials.nameplate}
        />
      </group>
      <group position={[-0.02, 1.16, 0.08]}>
        <mesh
          geometry={nodes.Cube025.geometry}
          material={materials.mars_2020_03}
        />
        <mesh
          geometry={nodes.Cube025_1.geometry}
          material={materials.mars_2020_01}
        />
        <mesh
          geometry={nodes.Cube025_2.geometry}
          material={materials.mars_2020_04}
        />
        <mesh
          geometry={nodes.Cube025_3.geometry}
          material={materials.mars_2020_02}
        />
        <mesh
          geometry={nodes.Cube025_4.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube025_5.geometry}
          material={materials.mars_2020_04_aluminum_r}
        />
      </group>
      <group position={[0.09, 0.68, 0.98]}>
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59000"
            ].geometry
          }
          material={materials["aluminum_black.001"]}
        />
        <mesh
          geometry={
            nodes[
              "10461516-101_A3-FRONT_HAZCAM_LENS_COVER_MOUNTING_BRACKET_59000_1"
            ].geometry
          }
          material={materials["mars_2020_04.001"]}
        />
      </group>
      <group
        position={[-0.49, 0.88, 1.23]}
        rotation={[-Math.PI, 1.57, 0]}
        scale={0}
      >
        <mesh
          geometry={
            nodes[
              "CEK_M2020_BLANK_SUPPORT_STRUTS_05_A1-BLANK_SUPPORT_STRUTS_1000"
            ].geometry
          }
          material={materials.sample_handling_door}
        />
        <mesh
          geometry={
            nodes[
              "CEK_M2020_BLANK_SUPPORT_STRUTS_05_A1-BLANK_SUPPORT_STRUTS_1000_1"
            ].geometry
          }
          material={materials.gunmetal}
        />
      </group>
      <group
        position={[0.54, 1.15, 0.87]}
        rotation={[-Math.PI, 0, 0]}
        scale={0.03}
      >
        <mesh
          geometry={nodes.Cylinder006.geometry}
          material={materials.mars_2020_07}
        />
        <mesh
          geometry={nodes.Cylinder006_1.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cylinder006_2.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cylinder006_3.geometry}
          material={materials.mars_2020_02_n}
        />
        <mesh
          geometry={nodes.Cylinder006_4.geometry}
          material={materials.bronze}
        />
        <mesh
          geometry={nodes.Cylinder006_5.geometry}
          material={materials.mars_2020_02}
        />
      </group>
      <group position={[-0.63, 1.24, 0.61]}>
        <mesh
          geometry={nodes.Cube008.geometry}
          material={materials.mars_2020_01_n}
        />
        <mesh
          geometry={nodes.Cube008_1.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube008_2.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube008_3.geometry}
          material={materials.mars_2020_06_brass2}
        />
        <mesh
          geometry={nodes.Cube008_4.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cube008_5.geometry}
          material={materials.mars_2020_02_n}
        />
        <mesh geometry={nodes.Cube008_6.geometry} material={materials.bronze} />
        <mesh geometry={nodes.Cube008_7.geometry} material={materials.blades} />
        <group position={[-0.04, 0.36, 0.13]}>
          <mesh
            geometry={nodes.Cube022.geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes.Cube022_1.geometry}
            material={materials.mars_2020_03}
          />
        </group>
        <group position={[0.07, 0.25, 0.08]}>
          <mesh
            geometry={nodes.Cube023.geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes.Cube023_1.geometry}
            material={materials.bronze}
          />
          <mesh
            geometry={nodes.Cube023_2.geometry}
            material={materials.aluminum}
          />
          <mesh
            geometry={nodes.Cube023_3.geometry}
            material={materials.mars_2020_01_n}
          />
        </group>
        <group position={[-0.14, 0.37, -0.06]}>
          <mesh
            geometry={nodes.Cylinder002.geometry}
            material={materials["aluminum.003"]}
          />
          <mesh
            geometry={nodes.Cylinder002_1.geometry}
            material={materials["mars_2020_03.002"]}
          />
        </group>
        <group position={[0.07, 0.55, 0.11]}>
          <mesh
            geometry={nodes.Cylinder016.geometry}
            material={materials.paint_white_base}
          />
          <mesh
            geometry={nodes.Cylinder016_1.geometry}
            material={materials.gunmetal}
          />
          <mesh
            geometry={nodes.Cylinder016_2.geometry}
            material={materials.mars_2020_06_brass2}
          />
          <mesh
            geometry={nodes.Cylinder016_3.geometry}
            material={materials.mars_2020_01_n}
          />
          <mesh
            geometry={nodes.Cylinder016_4.geometry}
            material={materials.bronze}
          />
          <mesh
            geometry={nodes.Cylinder016_5.geometry}
            material={materials.gunmetal_dark}
          />
          <mesh
            geometry={nodes.Cylinder016_6.geometry}
            material={materials["aluminum.001"]}
          />
          <mesh
            geometry={nodes.Cylinder016_7.geometry}
            material={materials.mars_2020_02_n}
          />
        </group>
      </group>
      <group position={[0, 0.71, -0.03]}>
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002"].geometry
          }
          material={materials.gunmetal}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_1"].geometry
          }
          material={materials.mars_2020_05_gunmetal}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_2"].geometry
          }
          material={materials.gunmetal_dark}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_3"].geometry
          }
          material={materials.aluminum}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_4"].geometry
          }
          material={materials.gray_krinkle}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_5"].geometry
          }
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={
            nodes["10272356-101_E-HORIZONTAL_SWINGARM_25223002_6"].geometry
          }
          material={materials.mars_2020_gunmetal_dark}
        />
      </group>
      <group
        position={[-0.02, 1.13, 0.81]}
        rotation={[2.71, -0.77, 0.43]}
        scale={[0.14, 0.25, 0.14]}
      >
        <mesh
          geometry={nodes.Cylinder054.geometry}
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={nodes.Cylinder054_1.geometry}
          material={materials.mars_2020_05_aluminum}
        />
        <mesh
          geometry={nodes.Cylinder054_2.geometry}
          material={materials.mars_2020_05_brass}
        />
        <mesh
          geometry={nodes.Cylinder054_3.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cylinder054_4.geometry}
          material={materials.mars_2020_05_gunmetal}
        />
        <mesh
          geometry={nodes.Cylinder054_5.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cylinder054_6.geometry}
          material={materials.mars_2020_01}
        />
        <mesh
          geometry={nodes.Cylinder054_7.geometry}
          material={materials.arm_graphics}
        />
        <mesh
          geometry={nodes.Cylinder054_8.geometry}
          material={materials.spring}
        />
      </group>
      <group position={[-0.02, 1.16, 0.08]}>
        <mesh
          geometry={nodes.Cube006.geometry}
          material={materials.mars_2020_04}
        />
        <mesh
          geometry={nodes.Cube006_1.geometry}
          material={materials.mars_2020_01}
        />
        <mesh
          geometry={nodes.Cube006_2.geometry}
          material={materials.mars_2020_02}
        />
        <mesh
          geometry={nodes.Cube006_3.geometry}
          material={materials.mars_2020_03}
        />
        <mesh
          geometry={nodes.Cube006_4.geometry}
          material={materials.mars_2020_06_n}
        />
        <mesh
          geometry={nodes.Cube006_5.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cube006_6.geometry}
          material={materials.gunmetal_dark}
        />
        <mesh
          geometry={nodes.Cube006_7.geometry}
          material={materials.paint_white_base}
        />
        <mesh
          geometry={nodes.Cube006_8.geometry}
          material={materials.mars_2020_06_brass2}
        />
        <mesh geometry={nodes.Cube006_9.geometry} material={materials.brass} />
        <mesh
          geometry={nodes.Cube006_10.geometry}
          material={materials.grey_brushed}
        />
        <mesh
          geometry={nodes.Cube006_11.geometry}
          material={materials.spring}
        />
        <mesh
          geometry={nodes.Cube006_12.geometry}
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={nodes.Cube006_13.geometry}
          material={materials.gunmetal}
        />
        <mesh
          geometry={nodes.Cube006_14.geometry}
          material={materials.aluminum_black}
        />
        <mesh
          geometry={nodes.Cube006_15.geometry}
          material={materials.mars_2020_04_aluminum_r}
        />
        <mesh
          geometry={nodes.Cube006_16.geometry}
          material={materials["aluminum_black.001"]}
        />
        <mesh
          geometry={nodes.Cube006_17.geometry}
          material={materials.blades}
        />
        <mesh
          geometry={nodes.Cube006_18.geometry}
          material={materials.covidPlaque}
        />
      </group>
      <group position={[-0.02, 1.16, 0.08]}>
        <mesh
          geometry={nodes.Cube021.geometry}
          material={materials.mars_2020_06}
        />
        <mesh
          geometry={nodes.Cube021_1.geometry}
          material={materials.gunmetal_dark}
        />
        <mesh
          geometry={nodes.Cube021_2.geometry}
          material={materials.aluminum}
        />
        <mesh
          geometry={nodes.Cube021_3.geometry}
          material={materials.mars_2020_05}
        />
        <mesh
          geometry={nodes.Cube021_4.geometry}
          material={materials.mars_2020_01}
        />
      </group>
    </group>
  );
};

useGLTF.preload("/Perseverance.glb");
