import { Html } from "@react-three/drei";
import { Button, Dropdown, MenuProps } from "antd";
import { useContext, useState } from "react";
import { Vector3 } from "three";
import RobotContext from "../../../../state/Robot";
import { RightOutlined } from "@ant-design/icons";
import LayoutContext from "../../../../state/Map";
import InstructionContext from "../../../../state/InstructionCon";
import { Position } from "../../../../models/Map";
import { vec2 } from "../../../../functions/Map";

interface Props {
  id: number;
  position: Vector3;
  type: "Wind" | "Temperature" | "Seismic";
  replay: boolean;
}

const GeneralSensor = ({ id, type, position, replay }: Props) => {
  const { addInstruction, setCurrentIndex, current_index, setCurrentObjectId } =
    useContext(InstructionContext);

  const { setCameraState, setInteractionMode } = useContext(RobotContext);
  const { menuModalIsOpen } = useContext(LayoutContext);

  const [showDropdown, setShowDropdown] = useState<boolean>(false);

  const tempPosList: Position[] = [];

  const items: MenuProps["items"] = [
    {
      label: "Pick Up",
      key: "1",
      onClick: () => {
        setShowDropdown(false);
        const newPosition: Position = {
          object: id,
          position: "robot",
        };
        tempPosList.push(newPosition);
        setCurrentIndex(current_index + 1);
        addInstruction(current_index, 10, tempPosList, "Pick Up");
      },
    },
    {
      label: "Walk To",
      key: "3",
      onClick: () => {
        setShowDropdown(false);
        const newPosition: Position = {
          object: "robot",
          position: vec2(position.x, position.z),
        };
        tempPosList.push(newPosition);
        setCurrentIndex(current_index + 1);
        addInstruction(current_index, 10, tempPosList, "Go To");
      },
    },
    {
      label: "Move",
      key: "4",
      onClick: () => {
        setShowDropdown(false);
        let tempCameraState = {} as any;
        tempCameraState.target = "Origo";
        tempCameraState.position = "God";
        setCameraState(tempCameraState);
        setInteractionMode("selectGrid");
        setCurrentObjectId(id);
      },
    },
  ];

  return (
    <group visible={true}>
      {showDropdown && !menuModalIsOpen && !replay ? (
        <Html center position={[position.x, position.y - 2, position.z]}>
          <Dropdown
            menu={{ items }}
            trigger={["click"]}
            onOpenChange={(e) => {
              if (!e) setShowDropdown(false);
            }}
          >
            <Button
              type="text"
              style={{
                background: "rgba(0,0,0,0.8)",
                color: "white",
                padding: "2px 10px 2px 10px",
                borderRadius: 10,
                userSelect: "none",
              }}
            >
              {type === "Wind"
                ? "Wind Sensor"
                : type === "Temperature"
                ? "Temperature Sensor"
                : type === "Seismic"
                ? "Seismic Sensor"
                : "Unknown Sensor"}
              <RightOutlined />
            </Button>
          </Dropdown>
        </Html>
      ) : (
        <Html></Html>
      )}
      <mesh position={position} onClick={() => setShowDropdown(!showDropdown)}>
        <boxGeometry args={[1, 1, 1]} />
        <meshStandardMaterial
          color={
            type === "Wind"
              ? "white"
              : type === "Temperature"
              ? "red"
              : type === "Seismic"
              ? "green"
              : "pink"
          }
        />
      </mesh>
    </group>
  );
};

export default GeneralSensor;
