import { Html, useGLTF } from "@react-three/drei";
import { Button, Dropdown, MenuProps } from "antd";
import { useContext, useState } from "react";
import { Vector3 } from "three";
import RobotContext from "../../../../state/Robot";
import { RightOutlined } from "@ant-design/icons";
import LayoutContext from "../../../../state/Map";
import InstructionContext from "../../../../state/InstructionCon";
import InventoryContext from "../../../../state/InventoryCon";
import { Position } from "../../../../models/Map";
import { vec2 } from "../../../../functions/Map";

interface Props {
  id: number;
  position: Vector3;
  replay: boolean;
}

const Stone = ({ id, position, replay }: Props) => {
  const { nodes, materials } = useGLTF("/Rock1.glb");
  const Cube = nodes.Cube as any;
  const { addInstruction, setCurrentIndex, current_index, setCurrentObjectId } =
    useContext(InstructionContext);

  const { cameraState, setCameraState, setInteractionMode } =
    useContext(RobotContext);
  const { menuModalIsOpen } = useContext(LayoutContext);
  const [showDropdown, setShowDropdown] = useState<boolean>(false);
  //const radiusX = Math.abs(robot.pos.x - position.x);
  //const radiusY = Math.abs(robot.pos.y - position.z);
  const { inventoryContents } = useContext(InventoryContext);
  const tempPosList: Position[] = [];

  const items: MenuProps["items"] = [
    {
      label: "Pick Up",
      key: "1",
      onClick: () => {
        if (replay) return;
        setShowDropdown(false);
        const newPosition: Position = {
          object: id,
          position: "robot",
        };
        tempPosList.push(newPosition);
        setCurrentIndex(current_index + 1);
        addInstruction(current_index, 10, tempPosList, "Pick Up");
      },
    },
    {
      label: "Walk To",
      key: "3",
      onClick: () => {
        setShowDropdown(false);
        const newPosition: Position = {
          object: "robot",
          position: vec2(position.x, position.z),
        };
        tempPosList.push(newPosition);
        setCurrentIndex(current_index + 1);
        addInstruction(current_index, 10, tempPosList, "Go To");
      },
    },
    {
      label: "Move",
      key: "4",
      onClick: () => {
        setShowDropdown(false);
        let tempCameraState = { ...cameraState };
        tempCameraState.target = "Origo";
        tempCameraState.zoom = 0.15;
        tempCameraState.position = "God";
        setCameraState(tempCameraState);
        setInteractionMode("selectGrid");
        setCurrentObjectId(id);
      },
    },
  ];

  return (
    <group>
      {showDropdown && !menuModalIsOpen ? (
        <Html center position={[position.x, position.y + 2, position.z]}>
          <Dropdown menu={{ items }} trigger={["click"]}>
            <Button
              type="text"
              style={{
                background: "rgba(0,0,0,0.8)",
                color: "white",
                padding: "2px 10px 2px 10px",
                borderRadius: 10,
                userSelect: "none",
              }}
            >
              Stone
              <RightOutlined />
            </Button>
          </Dropdown>
        </Html>
      ) : (
        <Html></Html>
      )}
      <mesh
        position={position}
        geometry={Cube.geometry}
        material={materials.Material}
        scale={[0.5, 0.25, 0.5]}
        onClick={(event) => {
          event.stopPropagation();
          setShowDropdown(!showDropdown);
        }}
      />
    </group>
  );
};

useGLTF.preload("/Rock1.glb");
export default Stone;
