import { Button, notification } from "antd";
import { forwardRef, useContext } from "react";
import { Position2 } from "../../../models/Data";
import FullScreenOverlayComponenetsContext from "../../../state/FullScreenOverlayLayout";
import MapContext from "../../../state/Map";
import RobotContext from "../../../state/Robot";
import Battery from "./components/Battery";
import ClockBar from "./components/ClockBar";
import CoordinateBox from "./components/CoordinateBox";
import CurrentPlanList from "./components/CurrentPlanList";
import ExitWindow from "./components/ExitWindow";
import InstructionList from "./components/InstructionList";
import InterestingAreaTable from "./components/InterestingAreaTable";
import Inventory from "./components/Inventory";
import RobotActionChoice from "./components/RobotActionChoice";
import RobotConclusion from "./components/RobotConclusion";
import SpeedBar from "./components/SpeedBar";
import ToggleAutopilot from "./components/ToggleAutopilot";
import ToggleComponents from "./components/ToggleComponents";
import "./styles/notification.css";
import MleWindow from "./components/MleWindow";

interface Props {
  switchAutopilot: () => void;
  switchRecord: () => void;
  replay: boolean;
}

const Overlay = forwardRef(
  ({ switchAutopilot, switchRecord, replay }: Props, ref: any) => {
    const {
      toggleActionLogTable,
      toggleInventory,
      toggleBattery,
      toggleSpeed,
      toggleClock,
      togglePath,
      togglePathhistory,
    } = useContext(FullScreenOverlayComponenetsContext);

    const { menuModalIsOpen, mleModalIsOpen } = useContext(MapContext);

    const { interactionMode } = useContext(RobotContext);

    return (
      <>
        {menuModalIsOpen ? (
          <div
            style={{
              position: "absolute",
              top: 250,
              zIndex: 10,
              display: "flex",
              width: "100%",
              justifyContent: "center",
            }}
          >
            <ExitWindow />
          </div>
        ) : interactionMode !== "none" ? (
          <>
            <CoordinateBox ref={ref} />
          </>
        ) : (
          <>
            {!replay ? (
              <div
                style={{
                  position: "absolute",
                  bottom: 120,
                  zIndex: 10,
                  display: "flex",
                  width: "100%",
                  justifyContent: "center",
                }}
              >
                <ToggleAutopilot
                  ref={ref}
                  switchAutopilot={switchAutopilot}
                  switchRecord={switchRecord}
                />
              </div>
            ) : (
              <></>
            )}

            <div
              style={{
                position: "absolute",
                top: 0,
                zIndex: 10,
                display: "flex",
                width: "100%",
                justifyContent: "flex-start",
              }}
            >
              <MleWindow />
            </div>

            <div
              style={{
                position: "absolute",
                left: 0,
                top: 250,
                zIndex: 10,
              }}
            >
              <CurrentPlanList ref={ref} />
            </div>
            <div
              style={{
                position: "fixed",
                right: 30,
                bottom: 30,
                zIndex: 13,
              }}
            >
              <RobotActionChoice ref={ref} />
            </div>
            <ToggleComponents ref={ref} />

            {/*<div style={{ position: "absolute", top: 30, left: 30 }}>
            <DataGenerator />
          </div> 
           <RobotConclusion ref={ref} />
          */}

            {!toggleInventory ? (
              <div
                style={{
                  position: "absolute",
                  bottom: !replay ? 30 : 100,
                  zIndex: 10,
                  display: "flex",
                  width: "100%",
                  justifyContent: "center",
                }}
              >
                <Inventory replay={replay} ref={ref} />
              </div>
            ) : (
              <></>
            )}

            {!toggleActionLogTable && !replay ? (
              <div
                style={{
                  zIndex: 13,
                  position: "absolute",
                  left: 30,
                  bottom: 30,
                }}
              >
                <InstructionList />
              </div>
            ) : (
              <></>
            )}

            {!toggleSpeed ? (
              <div
                style={{
                  position: "absolute",
                  bottom: 110,
                }}
              >
                <SpeedBar />
              </div>
            ) : (
              <></>
            )}

            {!toggleBattery ? (
              <div
                style={{
                  position: "absolute",
                  bottom: !replay ? 120 : 110,
                  right: !replay ? 565 : 470,
                }}
              >
                <Battery ref={ref} />
              </div>
            ) : (
              <></>
            )}

            {!toggleClock ? (
              <div style={{ position: "absolute", top: 30 }}>
                <ClockBar />
              </div>
            ) : (
              <></>
            )}
          </>
        )}
      </>
    );
  }
);

export default Overlay;
