import { Table } from "antd";
import type { ColumnsType } from "antd/es/table";
import { useContext } from "react";
import { ActivityLog } from "../../../../models/Supabase";
import LogContext from "../../../../state/Supabase";
import "../styles/table.css";

const ActionLogTable = () => {
  const { activityLog } = useContext(LogContext);

  const dataSource: ActivityLog[] = [];
  for (let i = 0; i < activityLog.length; i++) {
    dataSource.push({
      id: activityLog[i].id,
      created_at: activityLog[i].created_at,
      type: activityLog[i].type,
      description: activityLog[i].description,
    });
  }

  const columns: ColumnsType<ActivityLog> = [
    {
      title: "Type",
      dataIndex: "type",
      key: "type",
      filters: [
        { text: "Goal", value: "Goal" },
        { text: "Other", value: "Other" },
      ],
      onFilter: (value: any, record) => record.type.startsWith(value),
      filterSearch: true,
      width: "40%",
    },
    {
      title: "Description",
      dataIndex: "description",
      key: "description",
    },
    {
      title: "Created At",
      dataIndex: "created_at",
      key: "created_at",
      defaultSortOrder: "descend",
      sorter: (a, b) => a.id - b.id,
    },
  ];

  return (
    <div
      style={{
        display: "flex",
        alignItems: "center",
        flexDirection: "row",
        justifyContent: "space-between",
        borderRadius: "15px",
        background: "rgba(0, 0, 0, 0.6)",
        width: "400px",
        height: "200px",
      }}
    >
      <Table
        pagination={false}
        scroll={{ y: "160px", x: "400px" }}
        size="small"
        dataSource={activityLog}
        columns={columns}
      />
      <div
        style={{
          padding: 5,
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
        }}
      ></div>
    </div>
  );
};

export default ActionLogTable;
