import { forwardRef, useContext, useEffect, useState } from "react";
import { Button, Space, Typography, InputNumber, Select } from "antd";
import RobotContext from "../../../../state/Robot";
import { FaRobot } from "react-icons/fa";
import { MdSensors } from "react-icons/md";
import { ImEarth } from "react-icons/im";

const CameraSettings = forwardRef((props, ref: any) => {
  const { cameraState, setCameraState } = useContext(RobotContext);

  //Holds all the sensor ids
  const [sensorList, setSensorList] = useState<any[]>([]);

  //Checks for a change in sensors each 1s, if a change has happend it will update the
  // sensors list
  useEffect(() => {
    const interval = setInterval(() => {
      if (sensorList.length !== ref.current.sensors.length) {
        let tempSensorIds = [];
        for (let i = 0; i < ref.current.sensors.length; i++) {
          const currentSensor = ref.current.sensors[i];
          const sensorType =
            "wind_vec" in currentSensor
              ? "Wind"
              : "temp" in currentSensor
              ? "Temperature"
              : "Seismic";
          tempSensorIds.push({
            value: currentSensor.id,
            label: `${sensorType} ${currentSensor.id}`,
          });
        }
        setSensorList(tempSensorIds);
      }
    }, 1000);

    return () => clearInterval(interval);
  }, [ref, sensorList]);

  return (
    <div
      style={{
        display: "flex",
        flexDirection: "row",
        justifyContent: "space-between",
      }}
    >
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          alignItems: "center",
          justifyContent: "center",
          width: 220,
          height: 200,
          background: "rgba(0,0,0,0)",
        }}
      >
        <Space style={{ display: "flex", justifyContent: "center" }}>
          <Button
            type="link"
            style={{
              width: 65,
              height: 65,
              fontSize: 56,
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
            danger={cameraState.target === "Robot"}
            onClick={() => {
              let cs = { ...cameraState };
              cs.position = "Robot";
              cs.target = "Robot";
              setCameraState(cs);
            }}
          >
            <FaRobot />
          </Button>
          <Button
            type="link"
            style={{
              width: 65,
              height: 65,
              fontSize: 56,
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
            danger={cameraState.target === "Sensor"}
            onClick={() => {
              let cs = { ...cameraState };
              cs.target = "Sensor";
              setCameraState(cs);
            }}
          >
            <MdSensors />
          </Button>
          <Button
            type="link"
            style={{
              width: 65,
              height: 65,
              fontSize: 56,
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
            danger={cameraState.target === "Origo"}
            onClick={() => {
              let cs = { ...cameraState };
              cs.target = "Origo";
              cs.position = "God";
              setCameraState(cs);
            }}
          >
            <ImEarth />
          </Button>
        </Space>
        <Space style={{ display: "flex", justifyContent: "center" }}>
          <div
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "flex-start",
              flexDirection: "column",
            }}
          >
            <Select
              placeholder="Sensor ID"
              style={{ width: 200 }}
              options={sensorList}
              disabled={cameraState.target !== "Sensor"}
              onChange={(value: number | null) => {
                if (value === null) return;
                let cs = { ...cameraState };
                cs.target = "Sensor";
                cs.position = "Sensor";
                cs.sensorId = value;
                setCameraState(cs);
              }}
            />
          </div>
        </Space>
      </div>
    </div>
  );
});

export default CameraSettings;
