import { Card, Col, Divider, Row, Space, Typography } from "antd";
import { forwardRef, useEffect, useState } from "react";
import { GridElement, Position2 } from "../../../../models/Data";
import { getClosestGrid } from "../../../../functions/Objects";

const labelLayout = {
  md: 36,
  sm: 16,
  xs: 36,
};

const valueLayout = {
  md: 12,
  sm: 12,
  xs: 12,
};

const CoordinateBox = forwardRef((props, ref: any) => {
  const [coordinates, setCoordinates] = useState<Position2>({ x: 0, y: 0 });
  const [gridElement, setGridElement] = useState<GridElement | undefined>(
    undefined
  );

  useEffect(() => {
    const interval = setInterval(() => {
      if (ref.current.hoveredCoordinate !== coordinates)
        setCoordinates(ref.current.hoveredCoordinate);
      //
      const foundGrid = getClosestGrid(
        ref.current.hoveredCoordinate,
        ref.current.situationReport.gridElements
      );

      if (foundGrid) {
        setGridElement(foundGrid);
      } else {
        setGridElement(undefined);
      }
    }, 200);

    return () => clearInterval(interval);
  }, [ref, coordinates]);

  return (
    <div
      style={{
        position: "absolute",
        left: 30,
        top: 30,
        zIndex: 10,
        borderRadius: 10,
        width: 380,
        height: 360,
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
      }}
    >
      <Card style={{ width: 380, height: 360, background: "rgba(0,0,0,0.7)" }}>
        <Row>
          <Col {...labelLayout}>
            <Typography.Text strong type="secondary">
              Coordinate:
            </Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <Typography.Text>X: {coordinates.x.toFixed(1)}</Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <Typography.Text>Y:{coordinates.y.toFixed(1)}</Typography.Text>
          </Col>
          <Divider />
        </Row>
        <Row>
          <Col {...labelLayout}>
            <Typography.Text strong type="secondary">
              Alien:
            </Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <Typography.Text>
              {gridElement
                ? `${(gridElement.alien * 100).toFixed(1)}%`
                : "undefined"}
            </Typography.Text>
          </Col>
        </Row>
        <Row>
          <Col {...labelLayout}>
            <Typography.Text strong type="secondary">
              Earthquake:
            </Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <Typography.Text>
              {gridElement
                ? `${(gridElement.earthquake * 100).toFixed(1)}%`
                : "undefined"}
            </Typography.Text>
          </Col>
        </Row>
        <Row>
          <Col {...labelLayout}>
            <Typography.Text strong type="secondary">
              Tornado:
            </Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <Typography.Text>
              {gridElement
                ? `${(gridElement.tornado * 100).toFixed(1)}%`
                : "undefined"}
            </Typography.Text>
          </Col>
        </Row>
        <Row>
          <Col {...labelLayout}>
            <Typography.Text strong type="secondary">
              Volcano:
            </Typography.Text>
          </Col>
          <Col {...valueLayout}>
            <div style={{ display: "flex", flexDirection: "column" }}>
              {gridElement ? (
                <>
                  {" "}
                  <Typography.Text>
                    {gridElement
                      ? `None: ${(gridElement.volcano.none * 100).toFixed(1)}%`
                      : "undefined"}
                  </Typography.Text>
                  <Typography.Text>
                    {gridElement
                      ? `Dormant: ${(gridElement.volcano.dormant * 100).toFixed(
                          1
                        )}%`
                      : "undefined"}
                  </Typography.Text>
                  <Typography.Text>
                    {gridElement
                      ? `Erupt: ${(gridElement.volcano.erupt * 100).toFixed(
                          1
                        )}%`
                      : "undefined"}
                  </Typography.Text>
                </>
              ) : (
                <>undefined</>
              )}
            </div>
          </Col>
        </Row>
      </Card>
    </div>
  );
});

export default CoordinateBox;
