import { notification, Typography } from "antd";
import Title from "antd/es/typography/Title";
import { forwardRef, useEffect, useRef, useState } from "react";
import { Task } from "../../../../models/Data";
import styles from "../styles/HideScrollbar.module.scss";

interface TaskBoxProps {
  task: Task;
  currentIndex: number;
}

const TaskBox = ({ task, currentIndex }: TaskBoxProps) => {
  const [hover, setHover] = useState(false);

  return (
    <div
      style={{
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
        flexDirection: "column",
        height: task.id === currentIndex ? 60 : hover ? 60 : 50,
        width: task.id === currentIndex ? 200 : hover ? 200 : 180,
        background:
          task.id < currentIndex
            ? "linear-gradient(128deg, rgba(60,70,83,0.8) 0%, rgba(93,93,93,0.8) 50%)"
            : task.id > currentIndex
            ? "linear-gradient(128deg, rgba(128,183,255,0.8) 0%, rgba(255,255,255,0.8) 50%)"
            : "linear-gradient(128deg, rgba(60,70,83,0.8) 0%, rgba(0,153,255,0.8) 100%)",
        marginTop: 20,
        padding: 10,
        borderRadius: 20,
        boxShadow:
          task.id === currentIndex && hover
            ? "rgba(255, 255, 255, 0.24) 0px 0px 10px"
            : "rgba(0, 0, 0, 0.24) 0px 3px 8px",
        opacity: task.id === currentIndex ? 1.0 : hover ? 1.0 : 0.5,
        transition: "0.4s",
        userSelect: "none",
      }}
      onMouseEnter={() => setHover(true)}
      onMouseLeave={() => setHover(false)}
      onClick={() => console.log(task)}
    >
      <div style={{ width: "100%" }}>
        <Typography.Text strong style={{ fontSize: 10 }}>
          {task.id === currentIndex ? "CURRENT TASK" : ""}
        </Typography.Text>
      </div>

      <Title
        level={4}
        style={{
          margin: 0,
          color: "white",
          textDecoration: task.id < currentIndex ? "line-through" : "",
        }}
      >
        {task.type.toUpperCase()}
      </Title>
    </div>
  );
};

const CurrentPlanList = forwardRef((props, ref: any) => {
  const [currentIndex, setCurrentIndex] = useState<number>(2);
  const [plan, setPlan] = useState<Task[]>([]);

  //Variable that holds the prev. state of a plan
  const prevPlanDict = useRef<any>(ref.current.plan);

  //com.
  const scrollY = useRef<number>(0);

  //Checks if a plan has been updated, if it has the plan variable will be updated
  useEffect(() => {
    const interval = setInterval(() => {
      if (prevPlanDict.current !== ref.current.plan) {
        //Update prevPlanDict
        prevPlanDict.current = ref.current.plan;

        //The task received from task planning
        const taskData = ref.current.plan;

        //Iterating the dictornary to create objects
        let tempPlan = [] as Task[];
        for (var key in taskData) {
          if (key === "success") {
            if (!taskData[key])
              notification.open({
                message: "Task Planning",
                description: "A plan could not be found for the given task.",
                type: "error",
              });
          } else {
            let currentObj = taskData[key] as Task;
            currentObj.id = parseInt(key);
            tempPlan.push(currentObj);
          }
        }

        //Update the plan
        setPlan(tempPlan);
      }
    }, 1000);

    return () => clearInterval(interval);
  }, [ref, plan]);

  //com.
  useEffect(() => {
    const interval = setInterval(() => {
      if (scrollY.current === 0) return;
      //com.
      else if (scrollY.current < 0 && currentIndex > 1) {
        console.log("idx: " + currentIndex);
        console.log("len: " + plan.length);
        let tempIndex = currentIndex;
        tempIndex--;
        setCurrentIndex(tempIndex);
        scrollY.current = 0;
      }

      //com.
      else if (scrollY.current > 0 && currentIndex < plan.length - 2) {
        console.log("idx: " + currentIndex);
        console.log("len: " + plan.length);

        let tempIndex = currentIndex;
        tempIndex++;
        setCurrentIndex(tempIndex);
        scrollY.current = 0;
      }
    }, 800);

    return () => clearInterval(interval);
  }, [scrollY, currentIndex, plan]);

  return (
    <div
      className={styles.scrollBarCon}
      style={{
        height: 350,
        width: 250,
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
        flexDirection: "column",
        opacity: plan.length === 0 ? 0 : 1,
        transition: "0.4s",
      }}
      onWheel={(e) => {
        scrollY.current = e.deltaY;
      }}
    >
      {[...plan]
        .slice(currentIndex - 1, currentIndex + 2)
        .reverse()
        .map((task: Task) => (
          <TaskBox key={task.id} task={task} currentIndex={currentIndex} />
        ))}
    </div>
  );
});

export default CurrentPlanList;
