import { Instruction, Position } from "../../../../models/Map";
import { Table, Button, notification } from "antd";
import type { ColumnsType } from "antd/es/table";
import { useContext } from "react";
import InstructionContext from "../../../../state/InstructionCon";
import MQTTContext from "../../../../state/MQTT";
import "../styles/table.css";

const InstructionList = () => {
  const {
    instructionList,
    removeInstruction,
    clearInstructionList,
    setCurrentIndex,
  } = useContext(InstructionContext);

  const { send } = useContext(MQTTContext);

  const onSend = () => {
    var sendInstructions = ""; //full instruction list
    var tempPos = "";
    for (let i = 0; i < instructionList.length; i++) {
      //single instruction string
      //list of all positions
      //build position string for each instruction
      tempPos = tempPos.concat(
        `"${instructionList[i].location[0].object}":${JSON.stringify(
          instructionList[i].location[0].position
        )}`
      );
      if (i !== instructionList.length - 1) tempPos = tempPos + ",";
    }
    sendInstructions = `{"location":{${tempPos}},"min-battery":${instructionList[0].battery}}`; //build full instruction

    console.log(sendInstructions);
    send("ui/out/goal", JSON.parse(JSON.stringify(sendInstructions)));
    setCurrentIndex(0); // resets current index, future tasks will start from index 0.
    notification.open({
      message: "Instruction List",
      description: "A list of instructions has been sent to task planning.",
    });
  };

  const columns: ColumnsType<Instruction> = [
    {
      title: "Type",
      dataIndex: "type",
      key: "type",
      width: "40%",
    },
    {
      title: "Locations",
      dataIndex: "location",
      key: "location",
      width: "60%",
      render: (location) =>
        location.map((entry: Position, index: number) => (
          <div key={index}>
            {`${entry.object} : ${JSON.stringify(entry.position)}`}
          </div>
        )),
    },
  ];

  return (
    <div
      style={{
        transform: !(instructionList.length === 0)
          ? "translate(0, 0)"
          : "translate(-430px, 0)",
        transition: "all 0.3s ease-in",
        visibility: "visible",
      }}
    >
      <div
        style={{
          display: "flex",
          alignItems: "start",
          flexDirection: "row",
          justifyContent: "space-between",
          borderRadius: "15px",
          background: "rgba(0, 0, 0, 0.6)",
          width: "400px",
          height: "200px",
          userSelect: "none",
        }}
      >
        {/* using antd table*/}
        <Table
          onRow={(r) => ({
            onClick: () => removeInstruction(r.id),
          })}
          pagination={false}
          scroll={{ y: "160px", x: "400px" }}
          size="small"
          dataSource={instructionList}
          columns={columns}
          rowKey={(ins) => ins.id}
        />
        <div
          style={{
            padding: 5,
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
          }}
        ></div>
      </div>
      {/* send button */}
      <Button
        onClick={() => {
          onSend();
          clearInstructionList();
        }}
        style={{ borderRadius: 15, position: "absolute", top: 3, right: 3 }}
      >
        Send
      </Button>
    </div>
  );
};

export default InstructionList;
