import { Button, Table, notification } from "antd";
import { ColumnsType } from "antd/es/table";
import { useContext } from "react";
import { InterestingArea } from "../../../../models/Map";
import RobotContext from "../../../../state/Robot";
import MQTTContext from "../../../../state/MQTT";
import "../styles/table.css";

const columns: ColumnsType<InterestingArea> = [
  {
    title: "Interesting Area",
    render: ({ position }: InterestingArea) => (
      <>{`${JSON.stringify(position)}`}</>
    ),
  },
];

const InterestingAreaTable = () => {
  const {
    interestingAreas,
    cameraState,
    setInterestingAreas,
    setInteractionMode,
    setCameraState,
  } = useContext(RobotContext);

  const { send } = useContext(MQTTContext);

  const onSubmit = () => {
    setInterestingAreas([]);
    send("sit/in/request", {
      msgs: [
        {
          type: "requestAOT",
          points: interestingAreas.map((a) => {
            return [a.position.x, a.position.y];
          }),
        },
      ],
    });
    setInteractionMode("none");
    notification.open({
      message: "Request Area of Interest",
      description:
        "A list of interesting areas has been sent to situation report.",
    });
    let tempCameraState = { ...cameraState };
    tempCameraState.target = "Robot";
    tempCameraState.zoom = 1.0;
    tempCameraState.position = "Robot";
    setCameraState(tempCameraState);
  };

  return (
    <>
      <div
        style={{
          position: "absolute",
          right: 30,
          top: 30,
          zIndex: 10,
          background: "rgba(0,0,0,0.4)",
          borderRadius: 20,
          width: 400,
          height: 200,
          display: "flex",
        }}
      >
        <Table
          columns={columns}
          dataSource={[...interestingAreas]}
          pagination={false}
          scroll={{ y: 145 }}
        />
      </div>
      <div
        style={{
          display: "flex",
          justifyContent: "flex-end",
          width: "100%",
          position: "absolute",
          top: 40,
          right: 40,
          zIndex: 11,
        }}
      >
        <Button
          disabled={interestingAreas.length < 1}
          type="primary"
          onClick={() => onSubmit()}
        >
          Send
        </Button>
      </div>
    </>
  );
};

export default InterestingAreaTable;
