import { Space, Typography, Button, Card, Row, Col, Divider } from "antd";
import Title from "antd/es/typography/Title";
import { useContext } from "react";
import MapContext from "../../../../state/Map";
import { TbMountain } from "react-icons/tb";
import { WiEarthquake } from "react-icons/wi";
import { GiTornado } from "react-icons/gi";
import { RiAliensLine } from "react-icons/ri";

const labelLayout = {
  md: 36,
  sm: 16,
  xs: 36,
};

const valueLayout = {
  md: 36,
  sm: 36,
  xs: 36,
};

const MleWindow = () => {
  const { selectedMLE } = useContext(MapContext);

  if (!selectedMLE) return <></>;
  return (
    <div
      style={{
        position: "absolute",
        top: 30,
        left: 30,
        backgroundColor: "rgba(0,0,0,0.6)",
        padding: 20,
        borderRadius: 10,
        display: "flex",
        flexDirection: "column",
      }}
    >
      <Space size={"large"}>
        <div>
          <Title
            style={{
              margin: 0,
              color:
                selectedMLE?.alien.state.toLocaleLowerCase() === "no"
                  ? "green"
                  : "red",
            }}
          >
            <RiAliensLine />
          </Title>
          <Typography.Text style={{ color: "white" }}>
            {selectedMLE ? `${selectedMLE.alien.value * 100}%` : undefined}
          </Typography.Text>
        </div>
        <div>
          <Title
            style={{
              margin: 0,
              color:
                selectedMLE?.tornado.state.toLocaleLowerCase() === "no"
                  ? "green"
                  : "red",
            }}
          >
            <GiTornado />
          </Title>
          <Typography.Text style={{ color: "white" }}>
            {" "}
            {selectedMLE ? `${selectedMLE.tornado.value * 100}%` : undefined}
          </Typography.Text>
        </div>
        <div>
          <Title
            style={{
              margin: 0,
              color:
                selectedMLE?.earthquake.state.toLocaleLowerCase() === "no"
                  ? "green"
                  : "red",
            }}
          >
            <WiEarthquake />
          </Title>
          <Typography.Text style={{ color: "white" }}>
            {" "}
            {selectedMLE ? `${selectedMLE.earthquake.value * 100}%` : undefined}
          </Typography.Text>
        </div>
        <div>
          <Title
            style={{
              margin: 0,
              color:
                selectedMLE?.volcano.state.toLocaleLowerCase() === "none"
                  ? "green"
                  : selectedMLE?.volcano.state.toLocaleLowerCase() === "dormant"
                  ? "yellow"
                  : "red",
            }}
          >
            <TbMountain />
          </Title>
          <Typography.Text style={{ color: "white" }}>
            {selectedMLE ? `${selectedMLE.volcano.value * 100}%` : undefined}
          </Typography.Text>
        </div>
      </Space>
      <Divider style={{ margin: 10 }} />
      <Typography.Text style={{ color: "white" }}>
        {`Position:(${selectedMLE?.position.x},${selectedMLE?.position.y})`}
      </Typography.Text>
    </div>
  );
};

export default MleWindow;
