import React, { useContext, forwardRef, useEffect } from "react";
import { Button, Space } from "antd";
import { GiRayGun, GiCardPickup } from "react-icons/gi";
import MQTTContext from "../../../../state/MQTT";
import "../styles/Overlay.module.scss";

const RobotActionChoice = forwardRef((props, ref: any) => {
  const { config, send } = useContext(MQTTContext);
  const [autopilot, setAutopilot] = React.useState(false);

  useEffect(() => {
    const interval = setInterval(() => {
      setAutopilot(ref.current.autopilot);
    }, 1000);
    return () => clearInterval(interval);
  }, [ref, ref.current.autopilot]);

  return (
    <div
      style={{
        /* hidden out of sight depending on if autopilot is on */
        transform: !autopilot ? "translate(0, 0)" : "translate(130px, 0)",
        transition: "all 0.2s ease-in",
        visibility: !autopilot ? "visible" : "hidden",
        display: "flex",
        flexDirection: "row",
        justifyContent: "space-between",
        overflowX: "hidden",
      }}
    >
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          alignItems: "center",
          justifyContent: "center",
          width: 100,
          height: 150,
          background: "rgba(0,0,0,0.6)",
          borderRadius: 15,
        }}
      >
        <Space
          style={{
            display: "flex",
            justifyContent: "center",
            flexDirection: "column",
          }}
        >
          {/* button for shooting laser*/}
          <Button
            type="link"
            style={{
              width: 65,
              height: 65,
              fontSize: 56,
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
            onClick={() =>
              send(`sim/${config.id}/in/control`, {
                type: "shoot_laser",
                data: {},
              })
            }
            disabled={autopilot}
          >
            <GiRayGun />
          </Button>
          {/* manual pickup button */}
          <Button
            type="link"
            style={{
              width: 65,
              height: 65,
              fontSize: 56,
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
            }}
            onClick={() =>
              send(`sim/${config.id}/in/control`, { type: "pickup", data: {} })
            }
            disabled={autopilot}
          >
            <GiCardPickup />
          </Button>
        </Space>
      </div>
    </div>
  );
});

export default RobotActionChoice;
