import Title from "antd/es/typography/Title";
import { forwardRef, useEffect, useRef, useState } from "react";
import { Conclusion } from "../../../../models/Data";
import { TbMountain } from "react-icons/tb";
import { WiEarthquake } from "react-icons/wi";
import { GiTornado } from "react-icons/gi";
import { notification } from "antd";
import moment from "moment";

const RobotConclusion = forwardRef((props, ref: any) => {
  const [status, setStatus] = useState<number>(1);
  const [tornado, setTornado] = useState<number>(0);
  const [earthquake, setEarthquake] = useState<number>(0);
  const [vulcano, setVulcano] = useState<number>(0);

  //The different cases
  //status: 0=success 1=failed
  //tornado: 0=no 1=yes
  //earthquake: 0=no 1=yes
  //vulcano: 0=none 1=dormant 2=erupt

  const prevTimeCodeRed = useRef<number>(moment().unix());

  useEffect(() => {
    const interval = setInterval(() => {
      const tempConclusion = ref.current.conclusion as Conclusion;
      setStatus(tempConclusion.status);
      setTornado(tempConclusion.tornado);
      setEarthquake(tempConclusion.earthquake);
      setVulcano(tempConclusion.vulcano);

      //com
      if (
        moment().unix() - prevTimeCodeRed.current > 30 &&
        (tempConclusion.earthquake === 1 ||
          tempConclusion.tornado === 1 ||
          tempConclusion.vulcano === 2) &&
        tempConclusion.status === 0
      ) {
        notification.open({
          message: "Robot Conclusion",
          description: "Situation report shows a code red.",
          type: "error",
        });
        prevTimeCodeRed.current = moment().unix();
      }
    }, 1000);

    return () => clearInterval(interval);
  }, [ref]);

  return (
    <div
      style={{
        position: "absolute",
        top: 30,
        left: 30,
        backgroundColor: "rgba(0,0,0,0.8)",
        padding: 20,
        borderRadius: 10,
        display: "flex",
      }}
    >
      <Title
        style={{
          margin: "0px 20px 0px 0px",
          color: status !== 0 ? "gray" : tornado === 1 ? "red" : "green",
        }}
      >
        <GiTornado />
      </Title>
      <Title
        style={{
          margin: "0px 20px 0px 0px",
          color: status !== 0 ? "gray" : earthquake === 1 ? "red" : "green",
        }}
      >
        <WiEarthquake />
      </Title>
      <Title
        style={{
          margin: 0,
          color:
            status !== 0
              ? "gray"
              : vulcano === 2
              ? "red"
              : vulcano === 1
              ? "yellow"
              : "green",
        }}
      >
        <TbMountain />
      </Title>
    </div>
  );
});

export default RobotConclusion;
