import { forwardRef, useEffect, useState } from "react";
import { Button, Space } from "antd";
import { IoLogoGameControllerA } from "react-icons/io";
import { BiVideoRecording } from "react-icons/bi";

interface Props {
  switchAutopilot: () => void;
  switchRecord: () => void;
}

const ToggleAutopilot = forwardRef(
  ({ switchAutopilot, switchRecord }: Props, ref: any) => {
    const [autopilot, setAutopilot] = useState(true);
    const [record, setRecord] = useState(false);
    //get new data from payload each second, set autopilot to current value
    useEffect(() => {
      const interval = setInterval(() => {
        if (autopilot !== ref.current.autopilot)
          setAutopilot(ref.current.autopilot);
        if (record !== ref.current.record) setRecord(ref.current.record);
      }, 1000);

      return () => clearInterval(interval);
    }, [ref, autopilot, record]);

    return (
      <div
        style={{
          display: "flex",
          flexDirection: "row",
          justifyContent: "space-between",
        }}
      >
        <div
          style={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
            justifyContent: "center",
            width: 150,
            height: 50,
            background: "rgba(0,0,0,0.6)",
            borderRadius: 15,
          }}
        >
          <Space
            style={{
              display: "flex",
              justifyContent: "center",
              flexDirection: "row",
            }}
          >
            {/* button for manual mode*/}
            <Button
              type="link"
              style={{
                width: 65,
                height: 65,
                fontSize: 56,
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
              }}
              danger={autopilot}
              onClick={() => {
                switchAutopilot();
              }}
            >
              <IoLogoGameControllerA />
            </Button>
            {/* button to record for replay*/}
            <Button
              type="link"
              style={{
                width: 65,
                height: 65,
                fontSize: 56,
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
              }}
              danger={record}
              onClick={() => {
                switchRecord();
              }}
            >
              <BiVideoRecording />
            </Button>
          </Space>
        </div>
      </div>
    );
  }
);

export default ToggleAutopilot;
