import styles from "../styles/Overlay.module.scss";
import { Button, Checkbox, Space, InputNumber } from "antd";
import React, { forwardRef, useContext } from "react";
import FullScreenOverlayComponenetsContext from "../../../../state/FullScreenOverlayLayout";
import CameraSettings from "./CameraSettings";
import { AiFillSetting } from "react-icons/ai";

interface ToggleProps {
  settoggleToggleMenu: React.Dispatch<React.SetStateAction<boolean>>;
  toggleToggleMenu: boolean;
}

const ToggleButton = ({
  settoggleToggleMenu,
  toggleToggleMenu,
}: ToggleProps) => {
  return (
    // gearwheel icon
    <Button
      type="primary"
      onMouseEnter={() => settoggleToggleMenu(true)}
      style={{
        width: 30,
        height: 30,
        backgroundColor: "rgba(0, 0, 0, 0.1)",
        alignContent: "center",
        borderRadius: 15,
      }}
    >
      <div style={{ position: "absolute", right: 12 }}>
        <AiFillSetting style={{ fontSize: 28 }} />
      </div>
    </Button>
  );
};

const ToggleComponents = forwardRef((props, ref: any) => {
  const {
    toggleActionLogTable,
    toggleBattery,
    toggleInventory,
    toggleSpeed,
    toggleClock,
    togglePath,
    togglePathhistory,
    settoggleActionLogTable,
    settoggleBattery,
    settoggleInventory,
    settoggleSpeed,
    settoggleClock,
    settogglePath,
    settogglePathhistory,
  } = useContext(FullScreenOverlayComponenetsContext);
  const [toggleToggleMenu, settoggleToggleMenu] = React.useState(false);

  return (
    <>
      {!toggleToggleMenu ? (
        <div
          style={{
            display: "flex",
            flexDirection: "row",
            alignItems: "right",
            position: "absolute",
            top: 30,
            right: 30,
          }}
        >
          <ToggleButton
            settoggleToggleMenu={settoggleToggleMenu}
            toggleToggleMenu={toggleToggleMenu}
          />
        </div>
      ) : (
        <>
          <div
            onMouseLeave={() => settoggleToggleMenu(false)}
            style={{
              borderRadius: 15,
              background: "rgba(0, 0, 0, 0.6)",
              position: "absolute",
              top: 30,
              right: 30,
            }}
          >
            <div
              style={{
                width: "100%",
                display: "flex",
                flexDirection: "row",
                justifyContent: "right",
                alignItems: "right",
              }}
            >
              <ToggleButton
                settoggleToggleMenu={settoggleToggleMenu}
                toggleToggleMenu={toggleToggleMenu}
              />
            </div>
            {/* here are the different components that can be turned on or off in the menu*/}
            <div style={{ padding: 10, userSelect: "none" }}>
              <Space direction="vertical" size="small">
                <Checkbox
                  checked={!toggleActionLogTable}
                  onChange={
                    toggleActionLogTable
                      ? () => settoggleActionLogTable(false)
                      : () => settoggleActionLogTable(true)
                  }
                  className={styles.checkbox}
                >
                  Action log table
                </Checkbox>
                <Checkbox
                  checked={!toggleBattery}
                  onChange={
                    toggleBattery
                      ? () => settoggleBattery(false)
                      : () => settoggleBattery(true)
                  }
                  className={styles.checkbox}
                >
                  Battery
                </Checkbox>
                <Checkbox
                  checked={!toggleInventory}
                  onChange={
                    toggleInventory
                      ? () => settoggleInventory(false)
                      : () => settoggleInventory(true)
                  }
                  className={styles.checkbox}
                >
                  Inventory
                </Checkbox>
                <Checkbox
                  checked={!toggleSpeed}
                  onChange={
                    toggleSpeed
                      ? () => settoggleSpeed(false)
                      : () => settoggleSpeed(true)
                  }
                  className={styles.checkbox}
                >
                  Speed
                </Checkbox>
                <Checkbox
                  checked={!toggleClock}
                  onChange={
                    toggleClock
                      ? () => settoggleClock(false)
                      : () => settoggleClock(true)
                  }
                  className={styles.checkbox}
                >
                  Clock
                </Checkbox>

                <Checkbox
                  checked={!togglePath}
                  onChange={
                    togglePath
                      ? () => settogglePath(false)
                      : () => settogglePath(true)
                  }
                  className={styles.checkbox}
                >
                  Motion Path
                </Checkbox>

                <Checkbox
                  checked={!togglePathhistory}
                  onChange={
                    togglePathhistory
                      ? () => settogglePathhistory(false)
                      : () => settogglePathhistory(true)
                  }
                  className={styles.checkbox}
                >
                  Robot Path History
                </Checkbox>
                <CameraSettings ref={ref} />
              </Space>
            </div>
          </div>
        </>
      )}
    </>
  );
});

export default ToggleComponents;
