import { Divider, Layout as AntLayout, Menu, MenuProps } from "antd";
import { HomeOutlined } from "@ant-design/icons";
import React, { useState } from "react";
import { Link, useMatch, useNavigate } from "react-router-dom";
import styles from "../styles/Layout.module.scss";
import { MenuUnfoldOutlined, MenuFoldOutlined } from "@ant-design/icons";
import { CgController } from "react-icons/cg";
import { IoPlayCircleSharp } from "react-icons/io5";
import logo from "../../assets/logo.png";

type MenuItem = Required<MenuProps>["items"][number];

function getItem(
  label: React.ReactNode,
  key: React.Key,
  icon?: React.ReactNode,
  children?: MenuItem[]
): MenuItem {
  return {
    key,
    icon,
    children,
    label,
  } as MenuItem;
}

const Layout = ({ children }: { children: React.ReactNode }) => {
  const navigate = useNavigate();
  const match = useMatch("/:route/*");

  const selectedKeys = match?.params.route ? [match.params.route] : [""];
  const [collapsed, setCollapsed] = useState(false);

  const items: MenuProps["items"] = [
    getItem("Dashboard", "", <HomeOutlined />),
    getItem("Robot Interface", "map", <CgController />),
  ];

  const menuOnClick = (e: any) => {
    if (e.key === "divider" || e.key === "label") return;
    navigate(e.key);
  };

  return (
    <AntLayout hasSider className={styles.layout}>
      {selectedKeys.includes("replay") ||
      selectedKeys.includes("map") ||
      selectedKeys.includes("mobile") ? (
        <></>
      ) : (
        <AntLayout.Sider
          collapsed={collapsed}
          onCollapse={(value) => setCollapsed(value)}
          theme={"dark"}
          width={250}
          trigger={collapsed ? <MenuUnfoldOutlined /> : <MenuFoldOutlined />}
          className={styles.sider}
        >
          <Link
            to="/"
            style={{
              width: "100%",
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              marginTop: 20,
            }}
          >
            <div className={styles.logo}>
              <img className={styles.img} src={logo} alt="logo" />
            </div>
          </Link>
          <Divider />
          <Menu
            mode="inline"
            theme={"dark"}
            selectedKeys={selectedKeys}
            items={items}
            onClick={menuOnClick}
            defaultSelectedKeys={[""]}
          />
        </AntLayout.Sider>
      )}
      <AntLayout.Content
        className={styles.content}
        style={{ backgroundColor: "white" }}
      >
        <div className={styles.scrollBarCon}>{children}</div>
      </AntLayout.Content>
    </AntLayout>
  );
};

export default Layout;
