import { Button, Select, Slider, Tooltip, Typography } from "antd";
import { PlayCircleOutlined, PauseCircleOutlined } from "@ant-design/icons";
import { forwardRef, useEffect, useState } from "react";
import { frameCountToTimeString } from "../../helpers/Replay";

interface Props {
  updateFrame: (n: number) => void;
  changePlay: (b: boolean) => void;
  changeSpeed: (n: number) => void;
}

const ReplayController = forwardRef(
  ({ updateFrame, changePlay, changeSpeed }: Props, ref: any) => {
    const [isPlaying, setIsPlaying] = useState<boolean>(false);
    const [frame, setFrame] = useState<number>(0);
    const [speed, setSpeed] = useState<number>(1.0);
    const [size, setSize] = useState<number>(1);

    useEffect(() => {
      const interval = setInterval(() => {
        if (ref.current.isPlaying !== isPlaying)
          setIsPlaying(ref.current.isPlaying);
        if (ref.current.frame !== frame) setFrame(ref.current.frame);
        if (ref.current.size !== size) setSize(ref.current.size);
      }, 250);

      return () => clearInterval(interval);
    }, [ref, isPlaying, frame, size]);

    return (
      <div
        style={{
          width: "100%",
          height: 60,
          display: "flex",
          flexDirection: "row",
          justifyContent: "space-around",
          alignItems: "center",
        }}
      >
        <div
          style={{
            width: "10%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
          }}
        >
          <Button
            size="large"
            type="primary"
            shape="circle"
            onClick={() => changePlay(!ref.current.isPlaying)}
          >
            {isPlaying ? (
              <Tooltip title="Pause">
                <PauseCircleOutlined />
              </Tooltip>
            ) : (
              <Tooltip title="Play">
                <PlayCircleOutlined />
              </Tooltip>
            )}
          </Button>
        </div>
        <div
          style={{
            width: "10%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
          }}
        >
          <Typography.Text style={{ marginLeft: 10 }}>
            {frameCountToTimeString(frame)}/{frameCountToTimeString(size)}
          </Typography.Text>
        </div>
        <div
          style={{
            width: "70%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
          }}
        >
          <Slider
            style={{ width: "80vw" }}
            min={0}
            max={size}
            onChange={updateFrame}
            value={frame}
          />
        </div>
        <div
          style={{
            width: "10%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
          }}
        >
          <Select
            options={[
              { label: "0.25", value: 0.25 },
              { label: "1.0", value: 1.0 },
              { label: "2.0", value: 2.0 },
            ]}
            value={speed}
            placement={"topRight"}
            onChange={(value: number) => {
              setSpeed(value);
              changeSpeed(value);
            }}
          />
        </div>
      </div>
    );
  }
);

export default ReplayController;
