import { Instruction, Position } from "../models/Map";
import React, { useMemo, useState } from "react";
import { Vector2 } from "three";

interface State {
  instructionList: Instruction[];
  positionList: Position[];
  current_index: number;
  currentObjectId: number;
  addInstruction: (
    index: number,
    battery: number,
    positions: Position[],
    type: string
  ) => void;
  removeInstruction: (index: number) => void;
  addPostion: (object: number | "robot", position: Vector2 | "robot") => void;
  removePostion: (index: number) => void;
  clearInstructionList: () => void;
  setCurrentIndex: (v: number) => void;
  setCurrentObjectId: (n: number) => void;
}

const initialState: State = {
  instructionList: [],
  positionList: [],
  current_index: 0,
  currentObjectId: 0,
  addInstruction: () => {},
  removeInstruction: () => {},
  addPostion: () => {},
  removePostion: () => {},
  clearInstructionList: () => {},
  setCurrentIndex: () => {},
  setCurrentObjectId: () => {},
};

const InstructionContext = React.createContext<State>(initialState);

interface Props {
  children: React.ReactNode;
}

export const InstructionContextProvider = ({ children }: Props) => {
  const [instructionList, setInstructionList] = useState<Instruction[]>(
    initialState.instructionList
  );
  const [positionList, setPositionList] = useState<Position[]>(
    initialState.positionList
  );
  const [current_index, setCurrentIndex] = useState<number>(
    initialState.current_index
  );
  const [currentObjectId, setCurrentObjectId] = useState<number>(
    initialState.currentObjectId
  );

  const value: State = useMemo(() => {
    return {
      instructionList,
      positionList,
      current_index,
      currentObjectId,
      setCurrentIndex,
      addInstruction: (
        index: number,
        battery: number,
        positions: Position[],
        type: string
      ) => {
        const newInstruction: Instruction = {
          id: index,
          location: positions,
          battery: battery,
          type: type,
        };

        setInstructionList((prevState) => [...prevState, newInstruction]);
        //console.log("new: ");
        //console.log(JSON.stringify(newInstruction));
        //console.log("new: ");
        //console.log(JSON.stringify(newInstruction));
      },

      removeInstruction: (v: number) => {
        // problem: if we have 3 instructions and remove the one with index 1, then the list will contain indexes 0 and 2, is it a problem?
        let tempInstructionList = instructionList;
        tempInstructionList = tempInstructionList.filter(
          (inst, index) => inst.id !== v
        );
        setInstructionList(tempInstructionList);
        // resets index if list is empty
        if (tempInstructionList.length === 0) {
          setCurrentIndex(0);
        }
      },
      addPostion: (object: number | "robot", position: Vector2 | "robot") => {
        const newPosition: Position = {
          object: object,
          position: position,
        };
        setPositionList((prevState) => [...prevState, newPosition]);
      },
      removePostion: (v: number) => {},
      clearInstructionList: () => {
        let tempInstructionList: Instruction[] = [];
        setInstructionList(tempInstructionList);
      },
      setCurrentObjectId,
    };
  }, [instructionList, positionList, current_index, currentObjectId]);
  return (
    <InstructionContext.Provider value={value}>
      {children}
    </InstructionContext.Provider>
  );
};

export default InstructionContext;
