import React, { useMemo, useState } from "react";
import { MleElement } from "../models/Data";

interface State {
  menuModalIsOpen: boolean;
  mleModalIsOpen: boolean;
  selectedMLE: MleElement | undefined;
  setMenuModalIsOpen: (b: boolean) => void;
  setMleModalIsOpen: (b: boolean) => void;
  setSelectedMLE: (element: MleElement | undefined) => void;
}

const initialState: State = {
  menuModalIsOpen: false,
  mleModalIsOpen: false,
  selectedMLE: undefined,
  setMenuModalIsOpen: () => {},
  setMleModalIsOpen: () => {},
  setSelectedMLE: () => {},
};

const MapContext = React.createContext<State>(initialState);

interface Props {
  children: React.ReactNode;
}

export const MapContextProvider = ({ children }: Props) => {
  const [menuModalIsOpen, setMenuModalIsOpen] = useState<boolean>(
    initialState.menuModalIsOpen
  );
  const [mleModalIsOpen, setMleModalIsOpen] = useState<boolean>(
    initialState.mleModalIsOpen
  );
  const [selectedMLE, setSelectedMLE] = useState<MleElement | undefined>(
    initialState.selectedMLE
  );

  const value: State = useMemo(() => {
    return {
      menuModalIsOpen,
      mleModalIsOpen,
      selectedMLE,
      setMenuModalIsOpen,
      setMleModalIsOpen,
      setSelectedMLE,
    };
  }, [menuModalIsOpen, mleModalIsOpen, selectedMLE]);

  return <MapContext.Provider value={value}>{children}</MapContext.Provider>;
};

export default MapContext;
