import React, { useMemo, useState } from "react";
import { Item } from "../models/Inventory";
import { ItemList } from "../data/Items";
import { RobotData } from "../models/Data";
import { CameraState, InterestingArea } from "../models/Map";
import { Vector3 } from "three";

interface State {
  robot: RobotData;
  autopilot: boolean;
  shadowZone_X: number;
  cameraState: CameraState;
  speed: number;
  Lpower: number;
  Rpower: number;
  battery: number;
  items: Item[];
  interactionMode: "none" | "selectZone" | "selectGrid" | "selectSquare";
  interestingAreas: InterestingArea[];
  selectedPlaneSquare: Vector3 | undefined;
  selectedGrid: Vector3 | undefined;
  windSpeed: number[];
  temperature: number[];
  seismic: number[];
  satelliteImage: string;
  robotArmArray: number[];
  robotArmOpen: boolean;
  recentlyPressed: boolean;
  setRobot: (r: RobotData) => void;
  setAutopilot: (b: boolean) => void;
  setShadowZone: (v: number) => void;
  setCameraState: (s: CameraState) => void;
  setSpeed: (v: number) => void;
  setLpower: (v: number) => void;
  setRpower: (v: number) => void;
  setBattery: (v: number) => void;
  setItems: (items: Item[]) => void;
  addItem: (item: Item) => void;
  setInteractionMode: (
    mode: "none" | "selectZone" | "selectGrid" | "selectSquare"
  ) => void;
  setInterestingAreas: (areas: InterestingArea[]) => void;
  setSelectedPlaneSquare: (pos: Vector3 | undefined) => void;
  setSelectedGrid: (pos: Vector3 | undefined) => void;
  updateWindSpeed: (s: number) => void;
  updateTemperature: (s: number) => void;
  updateSeismic: (s: number) => void;
  setSatelliteImage: (img: string) => void;
  setRobotArmArray: (s: number[]) => void;
  setRobotArmOpen: (s: boolean) => void;
  setRecentlyPressed: (s: boolean) => void;
}
const initialState: State = {
  robot: {
    battery: 100,
    in_shadow: false,
    pos: { r: 0, x: 0, y: 0 },
    storage: [],
  },
  autopilot: true,
  shadowZone_X: 400,
  cameraState: { target: "Robot", position: "Robot", zoom: 1.0, sensorId: 1 },
  speed: 0,
  Lpower: 0,
  Rpower: 0,
  battery: 100,
  items: ItemList,
  interactionMode: "none",
  selectedPlaneSquare: undefined,
  selectedGrid: undefined,
  interestingAreas: [],
  windSpeed: [0, 0],
  temperature: [0, 0],
  seismic: [0, 0],
  satelliteImage: "",
  robotArmArray: [0, 0, 0, 0, 0, 0],
  robotArmOpen: false,
  recentlyPressed: false,
  setRobot: () => {},
  setAutopilot: () => {},
  setShadowZone: () => {},
  setCameraState: () => {},
  setSpeed: () => {},
  setLpower: () => {},
  setRpower: () => {},
  setBattery: () => {},
  setItems: () => {},
  addItem: () => {},
  setInteractionMode: () => {},
  setInterestingAreas: () => {},
  setSelectedPlaneSquare: () => {},
  setSelectedGrid: () => {},
  updateWindSpeed: () => {},
  updateTemperature: () => {},
  updateSeismic: () => {},
  setSatelliteImage: () => {},
  setRobotArmArray: () => {},
  setRobotArmOpen: () => {},
  setRecentlyPressed: () => {},
};

const RobotContext = React.createContext<State>(initialState);

interface Props {
  children: React.ReactNode;
}

export const RobotContextProvider = ({ children }: Props) => {
  const [robot, setRobot] = useState<RobotData>(initialState.robot);

  const [shadowZone_X, setShadowZone] = useState<number>(
    initialState.shadowZone_X
  );
  const [cameraState, setCameraState] = useState<CameraState>(
    initialState.cameraState
  );
  const [speed, setSpeed] = useState<number>(initialState.speed);
  const [Lpower, setLpower] = useState<number>(initialState.Lpower);
  const [Rpower, setRpower] = useState<number>(initialState.Rpower);
  const [battery, setBattery] = useState<number>(initialState.battery);
  const [items, setItems] = useState<Item[]>(initialState.items);
  const [autopilot, setAutopilot] = useState<boolean>(initialState.autopilot);
  const [interactionMode, setInteractionMode] = useState<
    "none" | "selectZone" | "selectGrid" | "selectSquare"
  >(initialState.interactionMode);
  const [selectedPlaneSquare, setSelectedPlaneSquare] = useState<
    Vector3 | undefined
  >(initialState.selectedGrid);
  const [selectedGrid, setSelectedGrid] = useState<Vector3 | undefined>(
    initialState.selectedGrid
  );
  const [interestingAreas, setInterestingAreas] = useState<InterestingArea[]>(
    initialState.interestingAreas
  );
  const [windSpeed, setWindSpeed] = useState<number[]>(initialState.windSpeed);
  const [temperature, setTemperature] = useState<number[]>(
    initialState.temperature
  );
  const [seismic, setSeismic] = useState<number[]>(initialState.seismic);

  const [satelliteImage, setSatelliteImage] = useState<string>(
    initialState.satelliteImage
  );
  const [robotArmArray, setRobotArmArray] = useState<number[]>(
    initialState.robotArmArray
  );

  const [robotArmOpen, setRobotArmOpen] = useState<boolean>(
    initialState.robotArmOpen
  );
  const [recentlyPressed, setRecentlyPressed] = useState<boolean>(false);

  const value: State = useMemo(() => {
    return {
      robot,
      autopilot,
      shadowZone_X,
      cameraState,
      speed,
      Lpower,
      Rpower,
      battery,
      items,
      interactionMode,
      interestingAreas,
      windSpeed,
      temperature,
      seismic,
      selectedPlaneSquare,
      selectedGrid,
      satelliteImage,
      robotArmArray,
      robotArmOpen,
      recentlyPressed,
      setRobot,
      setAutopilot,
      setShadowZone,
      setCameraState,
      setSpeed,
      setLpower,
      setRpower,
      setBattery,
      setItems,
      addItem: (item: Item) => {
        setItems((prevState) => [...prevState, item]);
      },
      setInteractionMode,
      setInterestingAreas,
      updateWindSpeed: (s: number) => {
        let temp = windSpeed;
        const a = temp[0];
        setWindSpeed([s, a]);
      },
      updateTemperature: (s: number) => {
        let temp = temperature;
        const a = temp[0];
        setTemperature([s, a]);
      },
      updateSeismic: (s: number) => {
        let temp = seismic;
        const a = temp[0];
        setSeismic([s, a]);
      },
      setSelectedPlaneSquare,
      setSelectedGrid,
      setSatelliteImage,
      setRobotArmArray,
      setRobotArmOpen,
      setRecentlyPressed,
    };
  }, [
    robot,
    autopilot,
    shadowZone_X,
    cameraState,
    speed,
    Lpower,
    Rpower,
    battery,
    items,
    interactionMode,
    interestingAreas,
    windSpeed,
    temperature,
    seismic,
    selectedPlaneSquare,
    selectedGrid,
    satelliteImage,
    robotArmArray,
    robotArmOpen,
    recentlyPressed,
  ]);

  return (
    <RobotContext.Provider value={value}>{children}</RobotContext.Provider>
  );
};

export default RobotContext;
